# Print an optspec for argparse to handle cmd's options that are independent of any subcommand.
function __fish_rabbitmqadmin_global_optspecs
	string join \n version c/config= N/node= H/host= P/port= U/base-uri= path-prefix= V/vhost= u/username= p/password= k/insecure use-tls tls-ca-cert-file= tls-cert-file= tls-key-file= timeout= q/quiet v/verbose non-interactive table-style= h/help
end

function __fish_rabbitmqadmin_needs_command
	# Figure out if the current invocation already has a command.
	set -l cmd (commandline -opc)
	set -e cmd[1]
	argparse -s (__fish_rabbitmqadmin_global_optspecs) -- $cmd 2>/dev/null
	or return
	if set -q argv[1]
		# Also print the command, so this can be used to figure out what it is.
		echo $argv[1]
		return 1
	end
	return 0
end

function __fish_rabbitmqadmin_using_subcommand
	set -l cmd (__fish_rabbitmqadmin_needs_command)
	test -z "$cmd"
	and return 1
	contains -- $cmd[1] $argv
end

complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -s c -l config -r -F
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -s N -l node -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -s H -l host -d 'HTTP API hostname to use when connecting' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -s P -l port -d 'HTTP API port to use when connecting' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -s U -l base-uri -d 'base HTTP API endpoint URI' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -l path-prefix -d 'use if target node uses a path prefix. Defaults to \'/api\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -s u -l username -d 'this user must have the permissions for HTTP API access, see https://rabbitmq.com/docs/management#permissions' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -s p -l password -d 'requires username to be specified via --username or in the config file' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -l tls-ca-cert-file -d 'Local path to a CA certificate file in the PEM format' -r -F
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -l tls-cert-file -d 'Local path to a client certificate file in the PEM format' -r -F
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -l tls-key-file -d 'Local path to a client private key file in the PEM format' -r -F
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -l timeout -d 'HTTP API request timeout in seconds. Must be greater than 0' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -l version -d 'Print version'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -s k -l insecure -d 'disables TLS peer (certificate chain) verification'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -l use-tls -d 'use TLS (HTTPS) for HTTP API requests '
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -s q -l quiet -d 'produce less output'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -s v -l verbose -d 'enable verbose logging of HTTP requests and responses'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -f -a "auth_attempts" -d 'Authentication attempt statistics'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -f -a "bindings" -d 'Operations on bindings'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -f -a "channels" -d 'Operations on channels'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -f -a "close" -d 'Closes connections'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -f -a "config_file" -d 'Operations on the local configuration file'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -f -a "connections" -d 'Operations on connections'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -f -a "declare" -d 'Creates or declares objects'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -f -a "definitions" -d 'Operations on definitions (everything except for messages: virtual hosts, queues, streams, exchanges, bindings, users, etc)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -f -a "delete" -d 'Deletes objects'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -f -a "deprecated_features" -d 'Operations on deprecated features'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -f -a "exchanges" -d 'Operations on exchanges'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -f -a "export" -d 'See \'definitions export\''
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -f -a "feature_flags" -d 'Operations on feature flags'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -f -a "federation" -d 'Operations on federation upstreams and links'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -f -a "get" -d 'Fetches message(s) from a queue or stream via polling. Only suitable for development and test environments.'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -f -a "global_parameters" -d 'Operations on global runtime parameters'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -f -a "health_check" -d 'Runs health checks'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -f -a "import" -d 'See \'definitions import\''
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -f -a "list" -d 'Lists objects'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -f -a "nodes" -d 'Node operations'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -f -a "operator_policies" -d 'Operations on operator policies'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -f -a "parameters" -d 'Operations on runtime parameters'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -f -a "passwords" -d 'Operations on passwords'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -f -a "permissions" -d 'Operations on user permissions'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -f -a "plugins" -d 'List enabled plugins'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -f -a "policies" -d 'Operations on policies'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -f -a "publish" -d 'Publishes (inefficiently) message(s) to a queue or a stream. Only suitable for development and test environments.'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -f -a "purge" -d 'Purges queues'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -f -a "queues" -d 'Operations on queues'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -f -a "rebalance" -d 'Rebalancing of leader replicas'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -f -a "shell" -d 'Shell-related operations'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -f -a "show" -d 'Overview, memory footprint breakdown, and more'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -f -a "shovels" -d 'Operations on shovels'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -f -a "streams" -d 'Operations on streams'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -f -a "tanzu" -d 'Tanzu RabbitMQ-specific commands'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -f -a "users" -d 'Operations on users'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -f -a "user_limits" -d 'Operations on per-user (resource) limits'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -f -a "vhosts" -d 'Virtual host operations'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -f -a "vhost_limits" -d 'Operations on virtual host (resource) limits'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_needs_command" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand auth_attempts; and not __fish_seen_subcommand_from stats help" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand auth_attempts; and not __fish_seen_subcommand_from stats help" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand auth_attempts; and not __fish_seen_subcommand_from stats help" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand auth_attempts; and not __fish_seen_subcommand_from stats help" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand auth_attempts; and not __fish_seen_subcommand_from stats help" -f -a "stats" -d 'Displays authentication attempt statistics for a cluster node'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand auth_attempts; and not __fish_seen_subcommand_from stats help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand auth_attempts; and __fish_seen_subcommand_from stats" -l node -d 'target node, must be a cluster member' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand auth_attempts; and __fish_seen_subcommand_from stats" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand auth_attempts; and __fish_seen_subcommand_from stats" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand auth_attempts; and __fish_seen_subcommand_from stats" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand auth_attempts; and __fish_seen_subcommand_from stats" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand auth_attempts; and __fish_seen_subcommand_from help" -f -a "stats" -d 'Displays authentication attempt statistics for a cluster node'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand auth_attempts; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand bindings; and not __fish_seen_subcommand_from declare delete list help" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand bindings; and not __fish_seen_subcommand_from declare delete list help" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand bindings; and not __fish_seen_subcommand_from declare delete list help" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand bindings; and not __fish_seen_subcommand_from declare delete list help" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand bindings; and not __fish_seen_subcommand_from declare delete list help" -f -a "declare" -d 'Creates a binding between a source exchange and a destination (a queue or an exchange)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand bindings; and not __fish_seen_subcommand_from declare delete list help" -f -a "delete" -d 'Deletes a binding'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand bindings; and not __fish_seen_subcommand_from declare delete list help" -f -a "list"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand bindings; and not __fish_seen_subcommand_from declare delete list help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand bindings; and __fish_seen_subcommand_from declare" -l source -d 'source exchange' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand bindings; and __fish_seen_subcommand_from declare" -l destination-type -d 'destination type: exchange or queue' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand bindings; and __fish_seen_subcommand_from declare" -l destination -d 'destination exchange/queue name' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand bindings; and __fish_seen_subcommand_from declare" -l routing-key -d 'routing key' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand bindings; and __fish_seen_subcommand_from declare" -l arguments -d 'additional arguments' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand bindings; and __fish_seen_subcommand_from declare" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand bindings; and __fish_seen_subcommand_from declare" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand bindings; and __fish_seen_subcommand_from declare" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand bindings; and __fish_seen_subcommand_from declare" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand bindings; and __fish_seen_subcommand_from delete" -l source -d 'source exchange' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand bindings; and __fish_seen_subcommand_from delete" -l destination-type -d 'destination type: exchange or queue' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand bindings; and __fish_seen_subcommand_from delete" -l destination -d 'destination exchange/queue name' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand bindings; and __fish_seen_subcommand_from delete" -l routing-key -d 'routing key' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand bindings; and __fish_seen_subcommand_from delete" -l arguments -d 'additional arguments' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand bindings; and __fish_seen_subcommand_from delete" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand bindings; and __fish_seen_subcommand_from delete" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand bindings; and __fish_seen_subcommand_from delete" -l idempotently -d 'do not consider 404 Not Found API responses to be errors'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand bindings; and __fish_seen_subcommand_from delete" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand bindings; and __fish_seen_subcommand_from delete" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand bindings; and __fish_seen_subcommand_from list" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand bindings; and __fish_seen_subcommand_from list" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand bindings; and __fish_seen_subcommand_from list" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand bindings; and __fish_seen_subcommand_from list" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand bindings; and __fish_seen_subcommand_from help" -f -a "declare" -d 'Creates a binding between a source exchange and a destination (a queue or an exchange)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand bindings; and __fish_seen_subcommand_from help" -f -a "delete" -d 'Deletes a binding'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand bindings; and __fish_seen_subcommand_from help" -f -a "list"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand bindings; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand channels; and not __fish_seen_subcommand_from list help" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand channels; and not __fish_seen_subcommand_from list help" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand channels; and not __fish_seen_subcommand_from list help" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand channels; and not __fish_seen_subcommand_from list help" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand channels; and not __fish_seen_subcommand_from list help" -f -a "list"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand channels; and not __fish_seen_subcommand_from list help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand channels; and __fish_seen_subcommand_from list" -l page -d 'page number (1-indexed)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand channels; and __fish_seen_subcommand_from list" -l page-size -d 'number of results per page (default: 100, max: 500)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand channels; and __fish_seen_subcommand_from list" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand channels; and __fish_seen_subcommand_from list" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand channels; and __fish_seen_subcommand_from list" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand channels; and __fish_seen_subcommand_from list" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand channels; and __fish_seen_subcommand_from help" -f -a "list"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand channels; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand close; and not __fish_seen_subcommand_from connection user_connections help" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand close; and not __fish_seen_subcommand_from connection user_connections help" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand close; and not __fish_seen_subcommand_from connection user_connections help" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand close; and not __fish_seen_subcommand_from connection user_connections help" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand close; and not __fish_seen_subcommand_from connection user_connections help" -f -a "connection" -d 'Closes a client connection'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand close; and not __fish_seen_subcommand_from connection user_connections help" -f -a "user_connections" -d 'Closes all connections that authenticated with a specific username'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand close; and not __fish_seen_subcommand_from connection user_connections help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand close; and __fish_seen_subcommand_from connection" -l name -d 'connection name (identifying string)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand close; and __fish_seen_subcommand_from connection" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand close; and __fish_seen_subcommand_from connection" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand close; and __fish_seen_subcommand_from connection" -l idempotently -d 'do not consider 404 Not Found API responses to be errors'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand close; and __fish_seen_subcommand_from connection" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand close; and __fish_seen_subcommand_from connection" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand close; and __fish_seen_subcommand_from user_connections" -s u -l username -d 'Name of the user whose connections to close' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand close; and __fish_seen_subcommand_from user_connections" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand close; and __fish_seen_subcommand_from user_connections" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand close; and __fish_seen_subcommand_from user_connections" -l idempotently -d 'do not consider 404 Not Found API responses to be errors'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand close; and __fish_seen_subcommand_from user_connections" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand close; and __fish_seen_subcommand_from user_connections" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand close; and __fish_seen_subcommand_from help" -f -a "connection" -d 'Closes a client connection'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand close; and __fish_seen_subcommand_from help" -f -a "user_connections" -d 'Closes all connections that authenticated with a specific username'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand close; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and not __fish_seen_subcommand_from show_path show add_node update_node delete_node help" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and not __fish_seen_subcommand_from show_path show add_node update_node delete_node help" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and not __fish_seen_subcommand_from show_path show add_node update_node delete_node help" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and not __fish_seen_subcommand_from show_path show add_node update_node delete_node help" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and not __fish_seen_subcommand_from show_path show add_node update_node delete_node help" -f -a "show_path" -d 'Shows the path to the local rabbitmqadmin configuration file'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and not __fish_seen_subcommand_from show_path show add_node update_node delete_node help" -f -a "show" -d 'Shows the contents of the local rabbitmqadmin configuration file'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and not __fish_seen_subcommand_from show_path show add_node update_node delete_node help" -f -a "add_node" -d 'Adds a new node entry to the local rabbitmqadmin configuration file'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and not __fish_seen_subcommand_from show_path show add_node update_node delete_node help" -f -a "update_node" -d 'Updates an existing node entry in the local rabbitmqadmin configuration file (or creates one if it does not exist)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and not __fish_seen_subcommand_from show_path show add_node update_node delete_node help" -f -a "delete_node" -d 'Deletes a node entry from the local rabbitmqadmin configuration file'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and not __fish_seen_subcommand_from show_path show add_node update_node delete_node help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and __fish_seen_subcommand_from show_path" -s V -l vhost -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and __fish_seen_subcommand_from show_path" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and __fish_seen_subcommand_from show_path" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and __fish_seen_subcommand_from show_path" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and __fish_seen_subcommand_from show" -s V -l vhost -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and __fish_seen_subcommand_from show" -l reveal-passwords -d 'reveal passwords in the output table instead of masked values (********)' -r -f -a "true\t''
false\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and __fish_seen_subcommand_from show" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and __fish_seen_subcommand_from show" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and __fish_seen_subcommand_from show" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and __fish_seen_subcommand_from add_node" -s N -l node -d 'node entry name (defaults to the hostname)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and __fish_seen_subcommand_from add_node" -s H -l host -d 'target node hostname' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and __fish_seen_subcommand_from add_node" -s P -l port -d 'target node HTTP API port' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and __fish_seen_subcommand_from add_node" -s U -l base-uri -d 'base HTTP API endpoint URI' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and __fish_seen_subcommand_from add_node" -l path-prefix -d 'HTTP API path prefix (defaults to \'/api\')' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and __fish_seen_subcommand_from add_node" -s u -l username -d 'username for authentication' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and __fish_seen_subcommand_from add_node" -s p -l password -d 'password for authentication' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and __fish_seen_subcommand_from add_node" -s s -l scheme -d 'connection scheme (http or https)' -r -f -a "http\t''
https\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and __fish_seen_subcommand_from add_node" -s V -l vhost -d 'default virtual host' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and __fish_seen_subcommand_from add_node" -l tls-ca-cert-file -d 'path to a CA certificate file in PEM format' -r -F
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and __fish_seen_subcommand_from add_node" -l tls-cert-file -d 'path to a client certificate file in PEM format' -r -F
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and __fish_seen_subcommand_from add_node" -l tls-key-file -d 'path to a client private key file in PEM format' -r -F
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and __fish_seen_subcommand_from add_node" -l table-style -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and __fish_seen_subcommand_from add_node" -l use-tls -d 'use TLS (HTTPS) for connections to this node'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and __fish_seen_subcommand_from add_node" -l create-file-if-missing -d 'create the configuration file if it does not exist'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and __fish_seen_subcommand_from add_node" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and __fish_seen_subcommand_from add_node" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and __fish_seen_subcommand_from update_node" -s N -l node -d 'node entry name (defaults to the hostname)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and __fish_seen_subcommand_from update_node" -s H -l host -d 'target node hostname' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and __fish_seen_subcommand_from update_node" -s P -l port -d 'target node HTTP API port' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and __fish_seen_subcommand_from update_node" -s U -l base-uri -d 'base HTTP API endpoint URI' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and __fish_seen_subcommand_from update_node" -l path-prefix -d 'HTTP API path prefix (defaults to \'/api\')' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and __fish_seen_subcommand_from update_node" -s u -l username -d 'username for authentication' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and __fish_seen_subcommand_from update_node" -s p -l password -d 'password for authentication' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and __fish_seen_subcommand_from update_node" -s s -l scheme -d 'connection scheme (http or https)' -r -f -a "http\t''
https\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and __fish_seen_subcommand_from update_node" -s V -l vhost -d 'default virtual host' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and __fish_seen_subcommand_from update_node" -l tls-ca-cert-file -d 'path to a CA certificate file in PEM format' -r -F
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and __fish_seen_subcommand_from update_node" -l tls-cert-file -d 'path to a client certificate file in PEM format' -r -F
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and __fish_seen_subcommand_from update_node" -l tls-key-file -d 'path to a client private key file in PEM format' -r -F
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and __fish_seen_subcommand_from update_node" -l table-style -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and __fish_seen_subcommand_from update_node" -l use-tls -d 'use TLS (HTTPS) for connections to this node'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and __fish_seen_subcommand_from update_node" -l create-file-if-missing -d 'create the configuration file if it does not exist'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and __fish_seen_subcommand_from update_node" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and __fish_seen_subcommand_from update_node" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and __fish_seen_subcommand_from delete_node" -s V -l vhost -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and __fish_seen_subcommand_from delete_node" -l table-style -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and __fish_seen_subcommand_from delete_node" -s N -l node -d 'node entry name to delete' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and __fish_seen_subcommand_from delete_node" -l create-file-if-missing -d 'create the configuration file if it does not exist'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and __fish_seen_subcommand_from delete_node" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and __fish_seen_subcommand_from delete_node" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and __fish_seen_subcommand_from help" -f -a "show_path" -d 'Shows the path to the local rabbitmqadmin configuration file'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and __fish_seen_subcommand_from help" -f -a "show" -d 'Shows the contents of the local rabbitmqadmin configuration file'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and __fish_seen_subcommand_from help" -f -a "add_node" -d 'Adds a new node entry to the local rabbitmqadmin configuration file'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and __fish_seen_subcommand_from help" -f -a "update_node" -d 'Updates an existing node entry in the local rabbitmqadmin configuration file (or creates one if it does not exist)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and __fish_seen_subcommand_from help" -f -a "delete_node" -d 'Deletes a node entry from the local rabbitmqadmin configuration file'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand config_file; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand connections; and not __fish_seen_subcommand_from close close_of_user list list_of_user help" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand connections; and not __fish_seen_subcommand_from close close_of_user list list_of_user help" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand connections; and not __fish_seen_subcommand_from close close_of_user list list_of_user help" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand connections; and not __fish_seen_subcommand_from close close_of_user list list_of_user help" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand connections; and not __fish_seen_subcommand_from close close_of_user list list_of_user help" -f -a "close" -d 'Closes a client connection'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand connections; and not __fish_seen_subcommand_from close close_of_user list list_of_user help" -f -a "close_of_user" -d 'Closes all connections that are authenticated with a specific username'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand connections; and not __fish_seen_subcommand_from close close_of_user list list_of_user help" -f -a "list"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand connections; and not __fish_seen_subcommand_from close close_of_user list list_of_user help" -f -a "list_of_user"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand connections; and not __fish_seen_subcommand_from close close_of_user list list_of_user help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand connections; and __fish_seen_subcommand_from close" -l name -d 'connection name (identifying string)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand connections; and __fish_seen_subcommand_from close" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand connections; and __fish_seen_subcommand_from close" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand connections; and __fish_seen_subcommand_from close" -l idempotently -d 'do not consider 404 Not Found API responses to be errors'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand connections; and __fish_seen_subcommand_from close" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand connections; and __fish_seen_subcommand_from close" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand connections; and __fish_seen_subcommand_from close_of_user" -s u -l username -d 'Name of the user whose connections should be closed' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand connections; and __fish_seen_subcommand_from close_of_user" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand connections; and __fish_seen_subcommand_from close_of_user" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand connections; and __fish_seen_subcommand_from close_of_user" -l idempotently -d 'do not consider 404 Not Found API responses to be errors'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand connections; and __fish_seen_subcommand_from close_of_user" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand connections; and __fish_seen_subcommand_from close_of_user" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand connections; and __fish_seen_subcommand_from list" -l page -d 'page number (1-indexed)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand connections; and __fish_seen_subcommand_from list" -l page-size -d 'number of results per page (default: 100, max: 500)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand connections; and __fish_seen_subcommand_from list" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand connections; and __fish_seen_subcommand_from list" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand connections; and __fish_seen_subcommand_from list" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand connections; and __fish_seen_subcommand_from list" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand connections; and __fish_seen_subcommand_from list_of_user" -s u -l username -d 'Name of the user whose connections should be listed' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand connections; and __fish_seen_subcommand_from list_of_user" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand connections; and __fish_seen_subcommand_from list_of_user" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand connections; and __fish_seen_subcommand_from list_of_user" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand connections; and __fish_seen_subcommand_from list_of_user" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand connections; and __fish_seen_subcommand_from help" -f -a "close" -d 'Closes a client connection'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand connections; and __fish_seen_subcommand_from help" -f -a "close_of_user" -d 'Closes all connections that are authenticated with a specific username'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand connections; and __fish_seen_subcommand_from help" -f -a "list"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand connections; and __fish_seen_subcommand_from help" -f -a "list_of_user"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand connections; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and not __fish_seen_subcommand_from user vhost permissions queue stream exchange binding parameter policy operator_policy vhost_limit user_limit help" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and not __fish_seen_subcommand_from user vhost permissions queue stream exchange binding parameter policy operator_policy vhost_limit user_limit help" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and not __fish_seen_subcommand_from user vhost permissions queue stream exchange binding parameter policy operator_policy vhost_limit user_limit help" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and not __fish_seen_subcommand_from user vhost permissions queue stream exchange binding parameter policy operator_policy vhost_limit user_limit help" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and not __fish_seen_subcommand_from user vhost permissions queue stream exchange binding parameter policy operator_policy vhost_limit user_limit help" -f -a "user" -d 'Creates a user'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and not __fish_seen_subcommand_from user vhost permissions queue stream exchange binding parameter policy operator_policy vhost_limit user_limit help" -f -a "vhost" -d 'Creates a virtual host'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and not __fish_seen_subcommand_from user vhost permissions queue stream exchange binding parameter policy operator_policy vhost_limit user_limit help" -f -a "permissions" -d 'grants permissions to a user'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and not __fish_seen_subcommand_from user vhost permissions queue stream exchange binding parameter policy operator_policy vhost_limit user_limit help" -f -a "queue" -d 'Declares a queue or a stream'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and not __fish_seen_subcommand_from user vhost permissions queue stream exchange binding parameter policy operator_policy vhost_limit user_limit help" -f -a "stream" -d 'Declares a stream'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and not __fish_seen_subcommand_from user vhost permissions queue stream exchange binding parameter policy operator_policy vhost_limit user_limit help" -f -a "exchange" -d 'Declares an exchange'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and not __fish_seen_subcommand_from user vhost permissions queue stream exchange binding parameter policy operator_policy vhost_limit user_limit help" -f -a "binding" -d 'Creates a binding between a source exchange and a destination (a queue or an exchange)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and not __fish_seen_subcommand_from user vhost permissions queue stream exchange binding parameter policy operator_policy vhost_limit user_limit help" -f -a "parameter" -d 'Sets a runtime parameter'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and not __fish_seen_subcommand_from user vhost permissions queue stream exchange binding parameter policy operator_policy vhost_limit user_limit help" -f -a "policy" -d 'Creates or updates a policy'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and not __fish_seen_subcommand_from user vhost permissions queue stream exchange binding parameter policy operator_policy vhost_limit user_limit help" -f -a "operator_policy" -d 'Creates or updates an operator policy'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and not __fish_seen_subcommand_from user vhost permissions queue stream exchange binding parameter policy operator_policy vhost_limit user_limit help" -f -a "vhost_limit" -d 'Set a vhost limit'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and not __fish_seen_subcommand_from user vhost permissions queue stream exchange binding parameter policy operator_policy vhost_limit user_limit help" -f -a "user_limit" -d 'Set a user limit'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and not __fish_seen_subcommand_from user vhost permissions queue stream exchange binding parameter policy operator_policy vhost_limit user_limit help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from user" -l name -d 'username' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from user" -l password-hash -d 'salted password hash, see https://rabbitmq.com/docs/passwords' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from user" -l password -d 'prefer providing a hash, see https://rabbitmq.com/docs/passwords' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from user" -l hashing-algorithm -d 'The hashing algorithm to use: SHA256 or SHA512' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from user" -l tags -d 'a list of comma-separated tags' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from user" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from user" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from user" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from user" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from vhost" -l name -d 'virtual host name' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from vhost" -l default-queue-type -d 'default queue type, one of: classic, quorum, stream' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from vhost" -l description -d 'what\'s the purpose of this virtual host?' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from vhost" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from vhost" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from vhost" -l tracing -d 'should tracing be enabled for this virtual host?'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from vhost" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from vhost" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from permissions" -l username -d 'username' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from permissions" -l configure -d 'name pattern for configuration access' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from permissions" -l read -d 'name pattern for read access' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from permissions" -l write -d 'name pattern for write access' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from permissions" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from permissions" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from permissions" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from permissions" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from queue" -l name -d 'name' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from queue" -l type -d 'queue type' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from queue" -l durable -d 'should it persist after a restart' -r -f -a "true\t''
false\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from queue" -l auto-delete -d 'should it be deleted when the last consumer disconnects' -r -f -a "true\t''
false\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from queue" -l arguments -d 'additional queue arguments' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from queue" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from queue" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from queue" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from queue" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from stream" -l name -d 'name' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from stream" -l expiration -d 'stream expiration, e.g. 12h for 12 hours, 7D for 7 days, or 1M for 1 month' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from stream" -l max-length-bytes -d 'maximum stream length in bytes' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from stream" -l stream-max-segment-size-bytes -d 'maximum stream segment file length in bytes' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from stream" -l arguments -d 'additional stream arguments' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from stream" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from stream" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from stream" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from stream" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from exchange" -l name -d 'exchange name' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from exchange" -l type -d 'exchange type' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from exchange" -l durable -d 'should it persist after a restart' -r -f -a "true\t''
false\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from exchange" -l auto-delete -d 'should it be deleted when the last queue is unbound' -r -f -a "true\t''
false\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from exchange" -l arguments -d 'additional exchange arguments' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from exchange" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from exchange" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from exchange" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from exchange" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from binding" -l source -d 'source exchange' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from binding" -l destination-type -d 'destination type: exchange or queue' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from binding" -l destination -d 'destination exchange/queue name' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from binding" -l routing-key -d 'routing key' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from binding" -l arguments -d 'additional arguments' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from binding" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from binding" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from binding" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from binding" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from parameter" -l name -d 'parameter\'s name' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from parameter" -l component -d 'component (eg. federation)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from parameter" -l value -d 'parameter\'s value' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from parameter" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from parameter" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from parameter" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from parameter" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from policy" -l name -d 'policy name' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from policy" -l pattern -d 'the pattern that is used to match entity (queue, stream, exchange) names' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from policy" -l apply-to -d 'entities to apply to (queues, classic_queues, quorum_queues, streams, exchanges, all)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from policy" -l priority -d 'policy priority (only the policy with the highest priority is effective)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from policy" -l definition -d 'policy definition' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from policy" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from policy" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from policy" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from policy" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from operator_policy" -l name -d 'operator policy name' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from operator_policy" -l pattern -d 'queue/exchange name pattern' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from operator_policy" -l apply-to -d 'entities to apply to (queues, classic_queues, quorum_queues, streams, exchanges, all)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from operator_policy" -l priority -d 'policy priority (only the policy with the highest priority is effective)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from operator_policy" -l definition -d 'policy definition' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from operator_policy" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from operator_policy" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from operator_policy" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from operator_policy" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from vhost_limit" -l name -d 'limit name (eg. max-connections, max-queues)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from vhost_limit" -l value -d 'limit value' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from vhost_limit" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from vhost_limit" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from vhost_limit" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from vhost_limit" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from user_limit" -l username -d 'username' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from user_limit" -l name -d 'limit name (eg. max-connections, max-queues)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from user_limit" -l value -d 'limit value' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from user_limit" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from user_limit" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from user_limit" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from user_limit" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from help" -f -a "user" -d 'Creates a user'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from help" -f -a "vhost" -d 'Creates a virtual host'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from help" -f -a "permissions" -d 'grants permissions to a user'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from help" -f -a "queue" -d 'Declares a queue or a stream'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from help" -f -a "stream" -d 'Declares a stream'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from help" -f -a "exchange" -d 'Declares an exchange'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from help" -f -a "binding" -d 'Creates a binding between a source exchange and a destination (a queue or an exchange)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from help" -f -a "parameter" -d 'Sets a runtime parameter'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from help" -f -a "policy" -d 'Creates or updates a policy'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from help" -f -a "operator_policy" -d 'Creates or updates an operator policy'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from help" -f -a "vhost_limit" -d 'Set a vhost limit'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from help" -f -a "user_limit" -d 'Set a user limit'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand declare; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand definitions; and not __fish_seen_subcommand_from export export_from_vhost import import_into_vhost help" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand definitions; and not __fish_seen_subcommand_from export export_from_vhost import import_into_vhost help" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand definitions; and not __fish_seen_subcommand_from export export_from_vhost import import_into_vhost help" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand definitions; and not __fish_seen_subcommand_from export export_from_vhost import import_into_vhost help" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand definitions; and not __fish_seen_subcommand_from export export_from_vhost import import_into_vhost help" -f -a "export" -d 'Export cluster-wide definitions'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand definitions; and not __fish_seen_subcommand_from export export_from_vhost import import_into_vhost help" -f -a "export_from_vhost" -d 'Export definitions of a specific virtual host'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand definitions; and not __fish_seen_subcommand_from export export_from_vhost import import_into_vhost help" -f -a "import" -d 'Import cluster-wide definitions (of multiple virtual hosts)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand definitions; and not __fish_seen_subcommand_from export export_from_vhost import import_into_vhost help" -f -a "import_into_vhost" -d 'Import a virtual host-specific definitions file into a virtual host'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand definitions; and not __fish_seen_subcommand_from export export_from_vhost import import_into_vhost help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand definitions; and __fish_seen_subcommand_from export" -l file -d 'output file path' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand definitions; and __fish_seen_subcommand_from export" -s t -l transformations -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand definitions; and __fish_seen_subcommand_from export" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand definitions; and __fish_seen_subcommand_from export" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand definitions; and __fish_seen_subcommand_from export" -l stdout -d 'print result to the standard output stream'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand definitions; and __fish_seen_subcommand_from export" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand definitions; and __fish_seen_subcommand_from export" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand definitions; and __fish_seen_subcommand_from export_from_vhost" -l file -d 'output file path' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand definitions; and __fish_seen_subcommand_from export_from_vhost" -s t -l transformations -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand definitions; and __fish_seen_subcommand_from export_from_vhost" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand definitions; and __fish_seen_subcommand_from export_from_vhost" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand definitions; and __fish_seen_subcommand_from export_from_vhost" -l stdout -d 'print result to the standard output stream'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand definitions; and __fish_seen_subcommand_from export_from_vhost" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand definitions; and __fish_seen_subcommand_from export_from_vhost" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand definitions; and __fish_seen_subcommand_from import" -l file -d 'cluster-wide definitions JSON file path; mutually exclusive with --stdin' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand definitions; and __fish_seen_subcommand_from import" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand definitions; and __fish_seen_subcommand_from import" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand definitions; and __fish_seen_subcommand_from import" -l stdin -d 'read input JSON from the standard input stream, mutually exclusive with --file'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand definitions; and __fish_seen_subcommand_from import" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand definitions; and __fish_seen_subcommand_from import" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand definitions; and __fish_seen_subcommand_from import_into_vhost" -l file -d 'cluster-wide definitions JSON file path; mutually exclusive with --stdin' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand definitions; and __fish_seen_subcommand_from import_into_vhost" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand definitions; and __fish_seen_subcommand_from import_into_vhost" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand definitions; and __fish_seen_subcommand_from import_into_vhost" -l stdin -d 'read input JSON from the standard input stream, mutually exclusive with --file'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand definitions; and __fish_seen_subcommand_from import_into_vhost" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand definitions; and __fish_seen_subcommand_from import_into_vhost" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand definitions; and __fish_seen_subcommand_from help" -f -a "export" -d 'Export cluster-wide definitions'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand definitions; and __fish_seen_subcommand_from help" -f -a "export_from_vhost" -d 'Export definitions of a specific virtual host'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand definitions; and __fish_seen_subcommand_from help" -f -a "import" -d 'Import cluster-wide definitions (of multiple virtual hosts)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand definitions; and __fish_seen_subcommand_from help" -f -a "import_into_vhost" -d 'Import a virtual host-specific definitions file into a virtual host'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand definitions; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and not __fish_seen_subcommand_from user vhost permissions queue stream exchange binding parameter policy operator_policy vhost_limit user_limit shovel help" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and not __fish_seen_subcommand_from user vhost permissions queue stream exchange binding parameter policy operator_policy vhost_limit user_limit shovel help" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and not __fish_seen_subcommand_from user vhost permissions queue stream exchange binding parameter policy operator_policy vhost_limit user_limit shovel help" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and not __fish_seen_subcommand_from user vhost permissions queue stream exchange binding parameter policy operator_policy vhost_limit user_limit shovel help" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and not __fish_seen_subcommand_from user vhost permissions queue stream exchange binding parameter policy operator_policy vhost_limit user_limit shovel help" -f -a "user" -d 'Deletes a user'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and not __fish_seen_subcommand_from user vhost permissions queue stream exchange binding parameter policy operator_policy vhost_limit user_limit shovel help" -f -a "vhost" -d 'Deletes a virtual host'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and not __fish_seen_subcommand_from user vhost permissions queue stream exchange binding parameter policy operator_policy vhost_limit user_limit shovel help" -f -a "permissions" -d 'Revokes user permissions to a given vhost'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and not __fish_seen_subcommand_from user vhost permissions queue stream exchange binding parameter policy operator_policy vhost_limit user_limit shovel help" -f -a "queue" -d 'Deletes a queue'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and not __fish_seen_subcommand_from user vhost permissions queue stream exchange binding parameter policy operator_policy vhost_limit user_limit shovel help" -f -a "stream" -d 'Deletes a stream'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and not __fish_seen_subcommand_from user vhost permissions queue stream exchange binding parameter policy operator_policy vhost_limit user_limit shovel help" -f -a "exchange" -d 'Deletes an exchange'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and not __fish_seen_subcommand_from user vhost permissions queue stream exchange binding parameter policy operator_policy vhost_limit user_limit shovel help" -f -a "binding" -d 'Deletes a binding'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and not __fish_seen_subcommand_from user vhost permissions queue stream exchange binding parameter policy operator_policy vhost_limit user_limit shovel help" -f -a "parameter" -d 'Clears a runtime parameter'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and not __fish_seen_subcommand_from user vhost permissions queue stream exchange binding parameter policy operator_policy vhost_limit user_limit shovel help" -f -a "policy" -d 'Deletes a policy'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and not __fish_seen_subcommand_from user vhost permissions queue stream exchange binding parameter policy operator_policy vhost_limit user_limit shovel help" -f -a "operator_policy" -d 'Deletes an operator policy'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and not __fish_seen_subcommand_from user vhost permissions queue stream exchange binding parameter policy operator_policy vhost_limit user_limit shovel help" -f -a "vhost_limit" -d 'delete a vhost limit'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and not __fish_seen_subcommand_from user vhost permissions queue stream exchange binding parameter policy operator_policy vhost_limit user_limit shovel help" -f -a "user_limit" -d 'Clears a user limit'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and not __fish_seen_subcommand_from user vhost permissions queue stream exchange binding parameter policy operator_policy vhost_limit user_limit shovel help" -f -a "shovel" -d 'Delete a shovel'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and not __fish_seen_subcommand_from user vhost permissions queue stream exchange binding parameter policy operator_policy vhost_limit user_limit shovel help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from user" -l name -d 'username' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from user" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from user" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from user" -l idempotently -d 'do not consider 404 Not Found API responses to be errors'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from user" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from user" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from vhost" -l name -d 'virtual host' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from vhost" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from vhost" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from vhost" -l idempotently -d 'do not consider 404 Not Found API responses to be errors'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from vhost" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from vhost" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from permissions" -l username -d 'username' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from permissions" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from permissions" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from permissions" -l idempotently -d 'do not consider 404 Not Found API responses to be errors'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from permissions" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from permissions" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from queue" -l name -d 'queue name' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from queue" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from queue" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from queue" -l idempotently -d 'do not consider 404 Not Found API responses to be errors'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from queue" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from queue" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from stream" -l name -d 'stream name' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from stream" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from stream" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from stream" -l idempotently -d 'do not consider 404 Not Found API responses to be errors'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from stream" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from stream" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from exchange" -l name -d 'exchange name' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from exchange" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from exchange" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from exchange" -l idempotently -d 'do not consider 404 Not Found API responses to be errors'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from exchange" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from exchange" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from binding" -l source -d 'source exchange' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from binding" -l destination-type -d 'destination type: exchange or queue' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from binding" -l destination -d 'destination exchange/queue name' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from binding" -l routing-key -d 'routing key' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from binding" -l arguments -d 'additional arguments' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from binding" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from binding" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from binding" -l idempotently -d 'do not consider 404 Not Found API responses to be errors'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from binding" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from binding" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from parameter" -l name -d 'parameter\'s name' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from parameter" -l component -d 'component (eg. federation-upstream)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from parameter" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from parameter" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from parameter" -l idempotently -d 'do not consider 404 Not Found API responses to be errors'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from parameter" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from parameter" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from policy" -l name -d 'policy name' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from policy" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from policy" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from policy" -l idempotently -d 'do not consider 404 Not Found API responses to be errors'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from policy" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from policy" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from operator_policy" -l name -d 'operator policy name' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from operator_policy" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from operator_policy" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from operator_policy" -l idempotently -d 'do not consider 404 Not Found API responses to be errors'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from operator_policy" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from operator_policy" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from vhost_limit" -l name -d 'limit name (eg. max-connections, max-queues)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from vhost_limit" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from vhost_limit" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from vhost_limit" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from vhost_limit" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from user_limit" -l username -d 'username' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from user_limit" -l name -d 'limit name (eg. max-connections, max-queues)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from user_limit" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from user_limit" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from user_limit" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from user_limit" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from shovel" -l name -d 'shovel name' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from shovel" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from shovel" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from shovel" -l idempotently -d 'do not consider 404 Not Found API responses to be errors'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from shovel" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from shovel" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from help" -f -a "user" -d 'Deletes a user'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from help" -f -a "vhost" -d 'Deletes a virtual host'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from help" -f -a "permissions" -d 'Revokes user permissions to a given vhost'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from help" -f -a "queue" -d 'Deletes a queue'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from help" -f -a "stream" -d 'Deletes a stream'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from help" -f -a "exchange" -d 'Deletes an exchange'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from help" -f -a "binding" -d 'Deletes a binding'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from help" -f -a "parameter" -d 'Clears a runtime parameter'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from help" -f -a "policy" -d 'Deletes a policy'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from help" -f -a "operator_policy" -d 'Deletes an operator policy'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from help" -f -a "vhost_limit" -d 'delete a vhost limit'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from help" -f -a "user_limit" -d 'Clears a user limit'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from help" -f -a "shovel" -d 'Delete a shovel'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand delete; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand deprecated_features; and not __fish_seen_subcommand_from list list_used help" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand deprecated_features; and not __fish_seen_subcommand_from list list_used help" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand deprecated_features; and not __fish_seen_subcommand_from list list_used help" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand deprecated_features; and not __fish_seen_subcommand_from list list_used help" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand deprecated_features; and not __fish_seen_subcommand_from list list_used help" -f -a "list"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand deprecated_features; and not __fish_seen_subcommand_from list list_used help" -f -a "list_used"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand deprecated_features; and not __fish_seen_subcommand_from list list_used help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand deprecated_features; and __fish_seen_subcommand_from list" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand deprecated_features; and __fish_seen_subcommand_from list" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand deprecated_features; and __fish_seen_subcommand_from list" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand deprecated_features; and __fish_seen_subcommand_from list" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand deprecated_features; and __fish_seen_subcommand_from list_used" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand deprecated_features; and __fish_seen_subcommand_from list_used" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand deprecated_features; and __fish_seen_subcommand_from list_used" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand deprecated_features; and __fish_seen_subcommand_from list_used" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand deprecated_features; and __fish_seen_subcommand_from help" -f -a "list"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand deprecated_features; and __fish_seen_subcommand_from help" -f -a "list_used"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand deprecated_features; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand exchanges; and not __fish_seen_subcommand_from bind declare delete list unbind help" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand exchanges; and not __fish_seen_subcommand_from bind declare delete list unbind help" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand exchanges; and not __fish_seen_subcommand_from bind declare delete list unbind help" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand exchanges; and not __fish_seen_subcommand_from bind declare delete list unbind help" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand exchanges; and not __fish_seen_subcommand_from bind declare delete list unbind help" -f -a "bind" -d 'Creates a binding between a source exchange and a destination (a queue or an exchange)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand exchanges; and not __fish_seen_subcommand_from bind declare delete list unbind help" -f -a "declare" -d 'Declares an exchange'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand exchanges; and not __fish_seen_subcommand_from bind declare delete list unbind help" -f -a "delete" -d 'Deletes an exchange'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand exchanges; and not __fish_seen_subcommand_from bind declare delete list unbind help" -f -a "list"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand exchanges; and not __fish_seen_subcommand_from bind declare delete list unbind help" -f -a "unbind" -d 'Deletes a binding'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand exchanges; and not __fish_seen_subcommand_from bind declare delete list unbind help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand exchanges; and __fish_seen_subcommand_from bind" -l source -d 'source exchange' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand exchanges; and __fish_seen_subcommand_from bind" -l destination-type -d 'destination type: exchange or queue' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand exchanges; and __fish_seen_subcommand_from bind" -l destination -d 'destination exchange/queue name' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand exchanges; and __fish_seen_subcommand_from bind" -l routing-key -d 'routing key' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand exchanges; and __fish_seen_subcommand_from bind" -l arguments -d 'additional arguments' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand exchanges; and __fish_seen_subcommand_from bind" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand exchanges; and __fish_seen_subcommand_from bind" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand exchanges; and __fish_seen_subcommand_from bind" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand exchanges; and __fish_seen_subcommand_from bind" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand exchanges; and __fish_seen_subcommand_from declare" -l name -d 'exchange name' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand exchanges; and __fish_seen_subcommand_from declare" -l type -d 'exchange type' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand exchanges; and __fish_seen_subcommand_from declare" -l durable -d 'should it persist after a restart' -r -f -a "true\t''
false\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand exchanges; and __fish_seen_subcommand_from declare" -l auto-delete -d 'should it be deleted when the last queue is unbound' -r -f -a "true\t''
false\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand exchanges; and __fish_seen_subcommand_from declare" -l arguments -d 'additional exchange arguments' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand exchanges; and __fish_seen_subcommand_from declare" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand exchanges; and __fish_seen_subcommand_from declare" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand exchanges; and __fish_seen_subcommand_from declare" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand exchanges; and __fish_seen_subcommand_from declare" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand exchanges; and __fish_seen_subcommand_from delete" -l name -d 'exchange name' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand exchanges; and __fish_seen_subcommand_from delete" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand exchanges; and __fish_seen_subcommand_from delete" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand exchanges; and __fish_seen_subcommand_from delete" -l idempotently -d 'do not consider 404 Not Found API responses to be errors'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand exchanges; and __fish_seen_subcommand_from delete" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand exchanges; and __fish_seen_subcommand_from delete" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand exchanges; and __fish_seen_subcommand_from list" -l page -d 'page number (1-indexed)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand exchanges; and __fish_seen_subcommand_from list" -l page-size -d 'number of results per page (default: 100, max: 500)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand exchanges; and __fish_seen_subcommand_from list" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand exchanges; and __fish_seen_subcommand_from list" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand exchanges; and __fish_seen_subcommand_from list" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand exchanges; and __fish_seen_subcommand_from list" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand exchanges; and __fish_seen_subcommand_from unbind" -l source -d 'source exchange' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand exchanges; and __fish_seen_subcommand_from unbind" -l destination-type -d 'destination type: exchange or queue' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand exchanges; and __fish_seen_subcommand_from unbind" -l destination -d 'destination exchange/queue name' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand exchanges; and __fish_seen_subcommand_from unbind" -l routing-key -d 'routing key' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand exchanges; and __fish_seen_subcommand_from unbind" -l arguments -d 'additional arguments' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand exchanges; and __fish_seen_subcommand_from unbind" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand exchanges; and __fish_seen_subcommand_from unbind" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand exchanges; and __fish_seen_subcommand_from unbind" -l idempotently -d 'do not consider 404 Not Found API responses to be errors'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand exchanges; and __fish_seen_subcommand_from unbind" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand exchanges; and __fish_seen_subcommand_from unbind" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand exchanges; and __fish_seen_subcommand_from help" -f -a "bind" -d 'Creates a binding between a source exchange and a destination (a queue or an exchange)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand exchanges; and __fish_seen_subcommand_from help" -f -a "declare" -d 'Declares an exchange'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand exchanges; and __fish_seen_subcommand_from help" -f -a "delete" -d 'Deletes an exchange'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand exchanges; and __fish_seen_subcommand_from help" -f -a "list"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand exchanges; and __fish_seen_subcommand_from help" -f -a "unbind" -d 'Deletes a binding'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand exchanges; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand export; and not __fish_seen_subcommand_from definitions help" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand export; and not __fish_seen_subcommand_from definitions help" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand export; and not __fish_seen_subcommand_from definitions help" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand export; and not __fish_seen_subcommand_from definitions help" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand export; and not __fish_seen_subcommand_from definitions help" -f -a "definitions" -d 'Export cluster-wide definitions'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand export; and not __fish_seen_subcommand_from definitions help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand export; and __fish_seen_subcommand_from definitions" -l file -d 'output file path' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand export; and __fish_seen_subcommand_from definitions" -s t -l transformations -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand export; and __fish_seen_subcommand_from definitions" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand export; and __fish_seen_subcommand_from definitions" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand export; and __fish_seen_subcommand_from definitions" -l stdout -d 'print result to the standard output stream'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand export; and __fish_seen_subcommand_from definitions" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand export; and __fish_seen_subcommand_from definitions" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand export; and __fish_seen_subcommand_from help" -f -a "definitions" -d 'Export cluster-wide definitions'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand export; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand feature_flags; and not __fish_seen_subcommand_from list enable enable_all help" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand feature_flags; and not __fish_seen_subcommand_from list enable enable_all help" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand feature_flags; and not __fish_seen_subcommand_from list enable enable_all help" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand feature_flags; and not __fish_seen_subcommand_from list enable enable_all help" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand feature_flags; and not __fish_seen_subcommand_from list enable enable_all help" -f -a "list"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand feature_flags; and not __fish_seen_subcommand_from list enable enable_all help" -f -a "enable"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand feature_flags; and not __fish_seen_subcommand_from list enable enable_all help" -f -a "enable_all"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand feature_flags; and not __fish_seen_subcommand_from list enable enable_all help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand feature_flags; and __fish_seen_subcommand_from list" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand feature_flags; and __fish_seen_subcommand_from list" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand feature_flags; and __fish_seen_subcommand_from list" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand feature_flags; and __fish_seen_subcommand_from list" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand feature_flags; and __fish_seen_subcommand_from enable" -l name -d 'feature flag name (identifier)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand feature_flags; and __fish_seen_subcommand_from enable" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand feature_flags; and __fish_seen_subcommand_from enable" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand feature_flags; and __fish_seen_subcommand_from enable" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand feature_flags; and __fish_seen_subcommand_from enable" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand feature_flags; and __fish_seen_subcommand_from enable_all" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand feature_flags; and __fish_seen_subcommand_from enable_all" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand feature_flags; and __fish_seen_subcommand_from enable_all" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand feature_flags; and __fish_seen_subcommand_from enable_all" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand feature_flags; and __fish_seen_subcommand_from help" -f -a "list"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand feature_flags; and __fish_seen_subcommand_from help" -f -a "enable"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand feature_flags; and __fish_seen_subcommand_from help" -f -a "enable_all"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand feature_flags; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and not __fish_seen_subcommand_from list_all_upstreams declare_upstream declare_upstream_for_exchanges declare_upstream_for_queues delete_upstream list_all_links disable_tls_peer_verification_for_all_upstreams enable_tls_peer_verification_for_all_upstreams help" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and not __fish_seen_subcommand_from list_all_upstreams declare_upstream declare_upstream_for_exchanges declare_upstream_for_queues delete_upstream list_all_links disable_tls_peer_verification_for_all_upstreams enable_tls_peer_verification_for_all_upstreams help" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and not __fish_seen_subcommand_from list_all_upstreams declare_upstream declare_upstream_for_exchanges declare_upstream_for_queues delete_upstream list_all_links disable_tls_peer_verification_for_all_upstreams enable_tls_peer_verification_for_all_upstreams help" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and not __fish_seen_subcommand_from list_all_upstreams declare_upstream declare_upstream_for_exchanges declare_upstream_for_queues delete_upstream list_all_links disable_tls_peer_verification_for_all_upstreams enable_tls_peer_verification_for_all_upstreams help" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and not __fish_seen_subcommand_from list_all_upstreams declare_upstream declare_upstream_for_exchanges declare_upstream_for_queues delete_upstream list_all_links disable_tls_peer_verification_for_all_upstreams enable_tls_peer_verification_for_all_upstreams help" -f -a "list_all_upstreams"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and not __fish_seen_subcommand_from list_all_upstreams declare_upstream declare_upstream_for_exchanges declare_upstream_for_queues delete_upstream list_all_links disable_tls_peer_verification_for_all_upstreams enable_tls_peer_verification_for_all_upstreams help" -f -a "declare_upstream"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and not __fish_seen_subcommand_from list_all_upstreams declare_upstream declare_upstream_for_exchanges declare_upstream_for_queues delete_upstream list_all_links disable_tls_peer_verification_for_all_upstreams enable_tls_peer_verification_for_all_upstreams help" -f -a "declare_upstream_for_exchanges"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and not __fish_seen_subcommand_from list_all_upstreams declare_upstream declare_upstream_for_exchanges declare_upstream_for_queues delete_upstream list_all_links disable_tls_peer_verification_for_all_upstreams enable_tls_peer_verification_for_all_upstreams help" -f -a "declare_upstream_for_queues"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and not __fish_seen_subcommand_from list_all_upstreams declare_upstream declare_upstream_for_exchanges declare_upstream_for_queues delete_upstream list_all_links disable_tls_peer_verification_for_all_upstreams enable_tls_peer_verification_for_all_upstreams help" -f -a "delete_upstream"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and not __fish_seen_subcommand_from list_all_upstreams declare_upstream declare_upstream_for_exchanges declare_upstream_for_queues delete_upstream list_all_links disable_tls_peer_verification_for_all_upstreams enable_tls_peer_verification_for_all_upstreams help" -f -a "list_all_links"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and not __fish_seen_subcommand_from list_all_upstreams declare_upstream declare_upstream_for_exchanges declare_upstream_for_queues delete_upstream list_all_links disable_tls_peer_verification_for_all_upstreams enable_tls_peer_verification_for_all_upstreams help" -f -a "disable_tls_peer_verification_for_all_upstreams" -d 'Use only in case of emergency. Disables TLS peer verification for all federation upstreams.'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and not __fish_seen_subcommand_from list_all_upstreams declare_upstream declare_upstream_for_exchanges declare_upstream_for_queues delete_upstream list_all_links disable_tls_peer_verification_for_all_upstreams enable_tls_peer_verification_for_all_upstreams help" -f -a "enable_tls_peer_verification_for_all_upstreams" -d 'Enables TLS peer verification for all federation upstreams with provided [RabbitMQ node-local] certificate paths.'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and not __fish_seen_subcommand_from list_all_upstreams declare_upstream declare_upstream_for_exchanges declare_upstream_for_queues delete_upstream list_all_links disable_tls_peer_verification_for_all_upstreams enable_tls_peer_verification_for_all_upstreams help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from list_all_upstreams" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from list_all_upstreams" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from list_all_upstreams" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from list_all_upstreams" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from declare_upstream" -l name -d 'upstream name (identifier)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from declare_upstream" -l uri -d 'the URI to use to connect to this upstream' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from declare_upstream" -l reconnect-delay -d 'Reconnection delay in seconds' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from declare_upstream" -l trust-user-id -d 'If set to true, federation will pass through any validated user-id from the upstream, even though it cannot validate it' -r -f -a "true\t''
false\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from declare_upstream" -l prefetch-count -d 'The prefetch value to use with internal consumers' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from declare_upstream" -l ack-mode -d 'Accepted values are: on-confirm, on-publish, no-ack' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from declare_upstream" -l queue-name -d 'queue federation: the queue name to use on the upstream. Defaults to the federated queue name' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from declare_upstream" -l consumer-tag -d 'Custom consumer tag to use for the internal federation consumer' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from declare_upstream" -l exchange-name -d 'exchange federation: the exchange name to use on the upstream. Defaults to the federated exchange name' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from declare_upstream" -l queue-type -d 'exchange federation: the type of the internal queue to use, one of: classic, quorum, stream' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from declare_upstream" -l max-hops -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from declare_upstream" -l bind-using-nowait -r -f -a "true\t''
false\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from declare_upstream" -l resource-cleanup-mode -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from declare_upstream" -l channel-use-mode -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from declare_upstream" -l ttl -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from declare_upstream" -l message-ttl -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from declare_upstream" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from declare_upstream" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from declare_upstream" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from declare_upstream" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from declare_upstream_for_exchanges" -l name -d 'upstream name (identifier)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from declare_upstream_for_exchanges" -l uri -d 'the URI to use to connect to this upstream' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from declare_upstream_for_exchanges" -l reconnect-delay -d 'Reconnection delay in seconds' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from declare_upstream_for_exchanges" -l trust-user-id -d 'If set to true, federation will pass through any validated user-id from the upstream, even though it cannot validate it' -r -f -a "true\t''
false\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from declare_upstream_for_exchanges" -l prefetch-count -d 'The prefetch value to use with internal consumers' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from declare_upstream_for_exchanges" -l ack-mode -d 'Accepted values are: on-confirm, on-publish, no-ack' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from declare_upstream_for_exchanges" -l exchange-name -d 'exchange federation: the exchange name to use on the upstream. Defaults to the federated exchange name' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from declare_upstream_for_exchanges" -l queue-type -d 'exchange federation: the type of the internal queue to use, one of: classic, quorum, stream' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from declare_upstream_for_exchanges" -l max-hops -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from declare_upstream_for_exchanges" -l resource-cleanup-mode -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from declare_upstream_for_exchanges" -l channel-use-mode -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from declare_upstream_for_exchanges" -l bind-using-nowait -r -f -a "true\t''
false\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from declare_upstream_for_exchanges" -l ttl -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from declare_upstream_for_exchanges" -l message-ttl -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from declare_upstream_for_exchanges" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from declare_upstream_for_exchanges" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from declare_upstream_for_exchanges" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from declare_upstream_for_exchanges" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from declare_upstream_for_queues" -l name -d 'upstream name (identifier)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from declare_upstream_for_queues" -l uri -d 'the URI to use to connect to this upstream' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from declare_upstream_for_queues" -l reconnect-delay -d 'Reconnection delay in seconds' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from declare_upstream_for_queues" -l trust-user-id -d 'If set to true, federation will pass through any validated user-id from the upstream, even though it cannot validate it' -r -f -a "true\t''
false\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from declare_upstream_for_queues" -l prefetch-count -d 'The prefetch value to use with internal consumers' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from declare_upstream_for_queues" -l ack-mode -d 'Accepted values are: on-confirm, on-publish, no-ack' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from declare_upstream_for_queues" -l bind-using-nowait -r -f -a "true\t''
false\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from declare_upstream_for_queues" -l channel-use-mode -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from declare_upstream_for_queues" -l queue-name -d 'queue federation: the queue name to use on the upstream. Defaults to the federated queue name' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from declare_upstream_for_queues" -l consumer-tag -d 'Custom consumer tag to use for the internal federation consumer' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from declare_upstream_for_queues" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from declare_upstream_for_queues" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from declare_upstream_for_queues" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from declare_upstream_for_queues" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from delete_upstream" -l name -d 'upstream name (identifier)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from delete_upstream" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from delete_upstream" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from delete_upstream" -l idempotently -d 'do not consider 404 Not Found API responses to be errors'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from delete_upstream" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from delete_upstream" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from list_all_links" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from list_all_links" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from list_all_links" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from list_all_links" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from disable_tls_peer_verification_for_all_upstreams" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from disable_tls_peer_verification_for_all_upstreams" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from disable_tls_peer_verification_for_all_upstreams" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from disable_tls_peer_verification_for_all_upstreams" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from enable_tls_peer_verification_for_all_upstreams" -l node-local-ca-certificate-bundle-path -d 'Path to the CA certificate bundle file on the target RabbitMQ node(s)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from enable_tls_peer_verification_for_all_upstreams" -l node-local-client-certificate-file-path -d 'Path to the client certificate file on the target RabbitMQ node(s)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from enable_tls_peer_verification_for_all_upstreams" -l node-local-client-private-key-file-path -d 'Path to the client private key file on the target RabbitMQ node(s)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from enable_tls_peer_verification_for_all_upstreams" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from enable_tls_peer_verification_for_all_upstreams" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from enable_tls_peer_verification_for_all_upstreams" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from enable_tls_peer_verification_for_all_upstreams" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from help" -f -a "list_all_upstreams"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from help" -f -a "declare_upstream"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from help" -f -a "declare_upstream_for_exchanges"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from help" -f -a "declare_upstream_for_queues"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from help" -f -a "delete_upstream"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from help" -f -a "list_all_links"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from help" -f -a "disable_tls_peer_verification_for_all_upstreams" -d 'Use only in case of emergency. Disables TLS peer verification for all federation upstreams.'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from help" -f -a "enable_tls_peer_verification_for_all_upstreams" -d 'Enables TLS peer verification for all federation upstreams with provided [RabbitMQ node-local] certificate paths.'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand federation; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand get; and not __fish_seen_subcommand_from messages help" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand get; and not __fish_seen_subcommand_from messages help" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand get; and not __fish_seen_subcommand_from messages help" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand get; and not __fish_seen_subcommand_from messages help" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand get; and not __fish_seen_subcommand_from messages help" -f -a "messages" -d 'Fetches (via polling, very inefficiently) message(s) from a queue. Only suitable for development and test environments'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand get; and not __fish_seen_subcommand_from messages help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand get; and __fish_seen_subcommand_from messages" -s q -l queue -d 'Target queue or stream name' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand get; and __fish_seen_subcommand_from messages" -s c -l count -d 'Maximum number of messages to consume' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand get; and __fish_seen_subcommand_from messages" -s a -l ack-mode -d 'Accepted values are: ack_requeue_false, reject_requeue_false, ack_requeue_true, reject_requeue_true' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand get; and __fish_seen_subcommand_from messages" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand get; and __fish_seen_subcommand_from messages" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand get; and __fish_seen_subcommand_from messages" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand get; and __fish_seen_subcommand_from messages" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand get; and __fish_seen_subcommand_from help" -f -a "messages" -d 'Fetches (via polling, very inefficiently) message(s) from a queue. Only suitable for development and test environments'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand get; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand global_parameters; and not __fish_seen_subcommand_from clear list set help" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand global_parameters; and not __fish_seen_subcommand_from clear list set help" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand global_parameters; and not __fish_seen_subcommand_from clear list set help" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand global_parameters; and not __fish_seen_subcommand_from clear list set help" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand global_parameters; and not __fish_seen_subcommand_from clear list set help" -f -a "clear" -d 'Clears (deletes) a global runtime parameter'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand global_parameters; and not __fish_seen_subcommand_from clear list set help" -f -a "list"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand global_parameters; and not __fish_seen_subcommand_from clear list set help" -f -a "set" -d 'Sets a global runtime parameter'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand global_parameters; and not __fish_seen_subcommand_from clear list set help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand global_parameters; and __fish_seen_subcommand_from clear" -l name -d 'parameter\'s name' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand global_parameters; and __fish_seen_subcommand_from clear" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand global_parameters; and __fish_seen_subcommand_from clear" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand global_parameters; and __fish_seen_subcommand_from clear" -l idempotently -d 'do not consider 404 Not Found API responses to be errors'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand global_parameters; and __fish_seen_subcommand_from clear" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand global_parameters; and __fish_seen_subcommand_from clear" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand global_parameters; and __fish_seen_subcommand_from list" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand global_parameters; and __fish_seen_subcommand_from list" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand global_parameters; and __fish_seen_subcommand_from list" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand global_parameters; and __fish_seen_subcommand_from list" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand global_parameters; and __fish_seen_subcommand_from set" -l name -d 'parameter\'s name' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand global_parameters; and __fish_seen_subcommand_from set" -l value -d 'parameter\'s value' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand global_parameters; and __fish_seen_subcommand_from set" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand global_parameters; and __fish_seen_subcommand_from set" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand global_parameters; and __fish_seen_subcommand_from set" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand global_parameters; and __fish_seen_subcommand_from set" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand global_parameters; and __fish_seen_subcommand_from help" -f -a "clear" -d 'Clears (deletes) a global runtime parameter'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand global_parameters; and __fish_seen_subcommand_from help" -f -a "list"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand global_parameters; and __fish_seen_subcommand_from help" -f -a "set" -d 'Sets a global runtime parameter'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand global_parameters; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand health_check; and not __fish_seen_subcommand_from local_alarms cluster_wide_alarms node_is_quorum_critical deprecated_features_in_use port_listener protocol_listener help" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand health_check; and not __fish_seen_subcommand_from local_alarms cluster_wide_alarms node_is_quorum_critical deprecated_features_in_use port_listener protocol_listener help" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand health_check; and not __fish_seen_subcommand_from local_alarms cluster_wide_alarms node_is_quorum_critical deprecated_features_in_use port_listener protocol_listener help" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand health_check; and not __fish_seen_subcommand_from local_alarms cluster_wide_alarms node_is_quorum_critical deprecated_features_in_use port_listener protocol_listener help" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand health_check; and not __fish_seen_subcommand_from local_alarms cluster_wide_alarms node_is_quorum_critical deprecated_features_in_use port_listener protocol_listener help" -f -a "local_alarms" -d 'Checks if there are any resource alarms in effect on the target node'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand health_check; and not __fish_seen_subcommand_from local_alarms cluster_wide_alarms node_is_quorum_critical deprecated_features_in_use port_listener protocol_listener help" -f -a "cluster_wide_alarms" -d 'Checks if there are any resource alarms in effect across the entire cluster'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand health_check; and not __fish_seen_subcommand_from local_alarms cluster_wide_alarms node_is_quorum_critical deprecated_features_in_use port_listener protocol_listener help" -f -a "node_is_quorum_critical" -d 'Fails if there are queues/streams with minimum online quorum (queues/streams that will lose their quorum if the target node shuts down)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand health_check; and not __fish_seen_subcommand_from local_alarms cluster_wide_alarms node_is_quorum_critical deprecated_features_in_use port_listener protocol_listener help" -f -a "deprecated_features_in_use" -d 'Fails if there are any deprecated features in use in the cluster'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand health_check; and not __fish_seen_subcommand_from local_alarms cluster_wide_alarms node_is_quorum_critical deprecated_features_in_use port_listener protocol_listener help" -f -a "port_listener" -d 'Verifies that there\'s a reachable TCP listener on the given port on the target node'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand health_check; and not __fish_seen_subcommand_from local_alarms cluster_wide_alarms node_is_quorum_critical deprecated_features_in_use port_listener protocol_listener help" -f -a "protocol_listener" -d 'Verifies that there\'s a reachable TCP listener on the given protocol alias on the target node'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand health_check; and not __fish_seen_subcommand_from local_alarms cluster_wide_alarms node_is_quorum_critical deprecated_features_in_use port_listener protocol_listener help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand health_check; and __fish_seen_subcommand_from local_alarms" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand health_check; and __fish_seen_subcommand_from local_alarms" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand health_check; and __fish_seen_subcommand_from local_alarms" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand health_check; and __fish_seen_subcommand_from local_alarms" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand health_check; and __fish_seen_subcommand_from cluster_wide_alarms" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand health_check; and __fish_seen_subcommand_from cluster_wide_alarms" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand health_check; and __fish_seen_subcommand_from cluster_wide_alarms" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand health_check; and __fish_seen_subcommand_from cluster_wide_alarms" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand health_check; and __fish_seen_subcommand_from node_is_quorum_critical" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand health_check; and __fish_seen_subcommand_from node_is_quorum_critical" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand health_check; and __fish_seen_subcommand_from node_is_quorum_critical" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand health_check; and __fish_seen_subcommand_from node_is_quorum_critical" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand health_check; and __fish_seen_subcommand_from deprecated_features_in_use" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand health_check; and __fish_seen_subcommand_from deprecated_features_in_use" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand health_check; and __fish_seen_subcommand_from deprecated_features_in_use" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand health_check; and __fish_seen_subcommand_from deprecated_features_in_use" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand health_check; and __fish_seen_subcommand_from port_listener" -l port -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand health_check; and __fish_seen_subcommand_from port_listener" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand health_check; and __fish_seen_subcommand_from port_listener" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand health_check; and __fish_seen_subcommand_from port_listener" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand health_check; and __fish_seen_subcommand_from port_listener" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand health_check; and __fish_seen_subcommand_from protocol_listener" -l protocol -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand health_check; and __fish_seen_subcommand_from protocol_listener" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand health_check; and __fish_seen_subcommand_from protocol_listener" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand health_check; and __fish_seen_subcommand_from protocol_listener" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand health_check; and __fish_seen_subcommand_from protocol_listener" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand health_check; and __fish_seen_subcommand_from help" -f -a "local_alarms" -d 'Checks if there are any resource alarms in effect on the target node'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand health_check; and __fish_seen_subcommand_from help" -f -a "cluster_wide_alarms" -d 'Checks if there are any resource alarms in effect across the entire cluster'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand health_check; and __fish_seen_subcommand_from help" -f -a "node_is_quorum_critical" -d 'Fails if there are queues/streams with minimum online quorum (queues/streams that will lose their quorum if the target node shuts down)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand health_check; and __fish_seen_subcommand_from help" -f -a "deprecated_features_in_use" -d 'Fails if there are any deprecated features in use in the cluster'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand health_check; and __fish_seen_subcommand_from help" -f -a "port_listener" -d 'Verifies that there\'s a reachable TCP listener on the given port on the target node'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand health_check; and __fish_seen_subcommand_from help" -f -a "protocol_listener" -d 'Verifies that there\'s a reachable TCP listener on the given protocol alias on the target node'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand health_check; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand import; and not __fish_seen_subcommand_from definitions help" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand import; and not __fish_seen_subcommand_from definitions help" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand import; and not __fish_seen_subcommand_from definitions help" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand import; and not __fish_seen_subcommand_from definitions help" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand import; and not __fish_seen_subcommand_from definitions help" -f -a "definitions" -d 'Prefer \'definitions import\''
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand import; and not __fish_seen_subcommand_from definitions help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand import; and __fish_seen_subcommand_from definitions" -l file -d 'JSON file with definitions' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand import; and __fish_seen_subcommand_from definitions" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand import; and __fish_seen_subcommand_from definitions" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand import; and __fish_seen_subcommand_from definitions" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand import; and __fish_seen_subcommand_from definitions" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand import; and __fish_seen_subcommand_from help" -f -a "definitions" -d 'Prefer \'definitions import\''
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand import; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and not __fish_seen_subcommand_from nodes users vhosts permissions connections user_connections channels queues exchanges bindings consumers parameters policies operator_policies vhost_limits user_limits feature_flags deprecated_features deprecated_features_in_use help" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and not __fish_seen_subcommand_from nodes users vhosts permissions connections user_connections channels queues exchanges bindings consumers parameters policies operator_policies vhost_limits user_limits feature_flags deprecated_features deprecated_features_in_use help" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and not __fish_seen_subcommand_from nodes users vhosts permissions connections user_connections channels queues exchanges bindings consumers parameters policies operator_policies vhost_limits user_limits feature_flags deprecated_features deprecated_features_in_use help" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and not __fish_seen_subcommand_from nodes users vhosts permissions connections user_connections channels queues exchanges bindings consumers parameters policies operator_policies vhost_limits user_limits feature_flags deprecated_features deprecated_features_in_use help" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and not __fish_seen_subcommand_from nodes users vhosts permissions connections user_connections channels queues exchanges bindings consumers parameters policies operator_policies vhost_limits user_limits feature_flags deprecated_features deprecated_features_in_use help" -f -a "nodes"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and not __fish_seen_subcommand_from nodes users vhosts permissions connections user_connections channels queues exchanges bindings consumers parameters policies operator_policies vhost_limits user_limits feature_flags deprecated_features deprecated_features_in_use help" -f -a "users"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and not __fish_seen_subcommand_from nodes users vhosts permissions connections user_connections channels queues exchanges bindings consumers parameters policies operator_policies vhost_limits user_limits feature_flags deprecated_features deprecated_features_in_use help" -f -a "vhosts"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and not __fish_seen_subcommand_from nodes users vhosts permissions connections user_connections channels queues exchanges bindings consumers parameters policies operator_policies vhost_limits user_limits feature_flags deprecated_features deprecated_features_in_use help" -f -a "permissions"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and not __fish_seen_subcommand_from nodes users vhosts permissions connections user_connections channels queues exchanges bindings consumers parameters policies operator_policies vhost_limits user_limits feature_flags deprecated_features deprecated_features_in_use help" -f -a "connections"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and not __fish_seen_subcommand_from nodes users vhosts permissions connections user_connections channels queues exchanges bindings consumers parameters policies operator_policies vhost_limits user_limits feature_flags deprecated_features deprecated_features_in_use help" -f -a "user_connections"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and not __fish_seen_subcommand_from nodes users vhosts permissions connections user_connections channels queues exchanges bindings consumers parameters policies operator_policies vhost_limits user_limits feature_flags deprecated_features deprecated_features_in_use help" -f -a "channels"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and not __fish_seen_subcommand_from nodes users vhosts permissions connections user_connections channels queues exchanges bindings consumers parameters policies operator_policies vhost_limits user_limits feature_flags deprecated_features deprecated_features_in_use help" -f -a "queues"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and not __fish_seen_subcommand_from nodes users vhosts permissions connections user_connections channels queues exchanges bindings consumers parameters policies operator_policies vhost_limits user_limits feature_flags deprecated_features deprecated_features_in_use help" -f -a "exchanges"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and not __fish_seen_subcommand_from nodes users vhosts permissions connections user_connections channels queues exchanges bindings consumers parameters policies operator_policies vhost_limits user_limits feature_flags deprecated_features deprecated_features_in_use help" -f -a "bindings"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and not __fish_seen_subcommand_from nodes users vhosts permissions connections user_connections channels queues exchanges bindings consumers parameters policies operator_policies vhost_limits user_limits feature_flags deprecated_features deprecated_features_in_use help" -f -a "consumers"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and not __fish_seen_subcommand_from nodes users vhosts permissions connections user_connections channels queues exchanges bindings consumers parameters policies operator_policies vhost_limits user_limits feature_flags deprecated_features deprecated_features_in_use help" -f -a "parameters"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and not __fish_seen_subcommand_from nodes users vhosts permissions connections user_connections channels queues exchanges bindings consumers parameters policies operator_policies vhost_limits user_limits feature_flags deprecated_features deprecated_features_in_use help" -f -a "policies"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and not __fish_seen_subcommand_from nodes users vhosts permissions connections user_connections channels queues exchanges bindings consumers parameters policies operator_policies vhost_limits user_limits feature_flags deprecated_features deprecated_features_in_use help" -f -a "operator_policies"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and not __fish_seen_subcommand_from nodes users vhosts permissions connections user_connections channels queues exchanges bindings consumers parameters policies operator_policies vhost_limits user_limits feature_flags deprecated_features deprecated_features_in_use help" -f -a "vhost_limits"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and not __fish_seen_subcommand_from nodes users vhosts permissions connections user_connections channels queues exchanges bindings consumers parameters policies operator_policies vhost_limits user_limits feature_flags deprecated_features deprecated_features_in_use help" -f -a "user_limits"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and not __fish_seen_subcommand_from nodes users vhosts permissions connections user_connections channels queues exchanges bindings consumers parameters policies operator_policies vhost_limits user_limits feature_flags deprecated_features deprecated_features_in_use help" -f -a "feature_flags"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and not __fish_seen_subcommand_from nodes users vhosts permissions connections user_connections channels queues exchanges bindings consumers parameters policies operator_policies vhost_limits user_limits feature_flags deprecated_features deprecated_features_in_use help" -f -a "deprecated_features"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and not __fish_seen_subcommand_from nodes users vhosts permissions connections user_connections channels queues exchanges bindings consumers parameters policies operator_policies vhost_limits user_limits feature_flags deprecated_features deprecated_features_in_use help" -f -a "deprecated_features_in_use"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and not __fish_seen_subcommand_from nodes users vhosts permissions connections user_connections channels queues exchanges bindings consumers parameters policies operator_policies vhost_limits user_limits feature_flags deprecated_features deprecated_features_in_use help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from nodes" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from nodes" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from nodes" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from nodes" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from users" -l page -d 'page number (1-indexed)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from users" -l page-size -d 'number of results per page (default: 100, max: 500)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from users" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from users" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from users" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from users" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from vhosts" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from vhosts" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from vhosts" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from vhosts" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from permissions" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from permissions" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from permissions" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from permissions" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from connections" -l page -d 'page number (1-indexed)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from connections" -l page-size -d 'number of results per page (default: 100, max: 500)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from connections" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from connections" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from connections" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from connections" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from user_connections" -s u -l username -d 'Name of the user whose connections should be listed' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from user_connections" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from user_connections" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from user_connections" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from user_connections" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from channels" -l page -d 'page number (1-indexed)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from channels" -l page-size -d 'number of results per page (default: 100, max: 500)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from channels" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from channels" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from channels" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from channels" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from queues" -l page -d 'page number (1-indexed)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from queues" -l page-size -d 'number of results per page (default: 100, max: 500)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from queues" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from queues" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from queues" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from queues" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from exchanges" -l page -d 'page number (1-indexed)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from exchanges" -l page-size -d 'number of results per page (default: 100, max: 500)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from exchanges" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from exchanges" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from exchanges" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from exchanges" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from bindings" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from bindings" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from bindings" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from bindings" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from consumers" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from consumers" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from consumers" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from consumers" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from parameters" -l component -d 'component (for example: federation-upstream, vhost-limits)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from parameters" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from parameters" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from parameters" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from parameters" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from policies" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from policies" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from policies" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from policies" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from operator_policies" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from operator_policies" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from operator_policies" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from operator_policies" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from vhost_limits" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from vhost_limits" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from vhost_limits" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from vhost_limits" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from user_limits" -l username -d 'username' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from user_limits" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from user_limits" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from user_limits" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from user_limits" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from feature_flags" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from feature_flags" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from feature_flags" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from feature_flags" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from deprecated_features" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from deprecated_features" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from deprecated_features" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from deprecated_features" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from deprecated_features_in_use" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from deprecated_features_in_use" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from deprecated_features_in_use" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from deprecated_features_in_use" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from help" -f -a "nodes"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from help" -f -a "users"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from help" -f -a "vhosts"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from help" -f -a "permissions"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from help" -f -a "connections"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from help" -f -a "user_connections"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from help" -f -a "channels"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from help" -f -a "queues"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from help" -f -a "exchanges"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from help" -f -a "bindings"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from help" -f -a "consumers"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from help" -f -a "parameters"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from help" -f -a "policies"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from help" -f -a "operator_policies"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from help" -f -a "vhost_limits"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from help" -f -a "user_limits"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from help" -f -a "feature_flags"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from help" -f -a "deprecated_features"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from help" -f -a "deprecated_features_in_use"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand list; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand nodes; and not __fish_seen_subcommand_from list memory_breakdown_in_percent memory_breakdown_in_bytes help" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand nodes; and not __fish_seen_subcommand_from list memory_breakdown_in_percent memory_breakdown_in_bytes help" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand nodes; and not __fish_seen_subcommand_from list memory_breakdown_in_percent memory_breakdown_in_bytes help" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand nodes; and not __fish_seen_subcommand_from list memory_breakdown_in_percent memory_breakdown_in_bytes help" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand nodes; and not __fish_seen_subcommand_from list memory_breakdown_in_percent memory_breakdown_in_bytes help" -f -a "list"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand nodes; and not __fish_seen_subcommand_from list memory_breakdown_in_percent memory_breakdown_in_bytes help" -f -a "memory_breakdown_in_percent" -d 'Provides a memory footprint breakdown (in percent) for the target node'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand nodes; and not __fish_seen_subcommand_from list memory_breakdown_in_percent memory_breakdown_in_bytes help" -f -a "memory_breakdown_in_bytes" -d 'Provides a memory footprint breakdown (in bytes) for the target node'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand nodes; and not __fish_seen_subcommand_from list memory_breakdown_in_percent memory_breakdown_in_bytes help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand nodes; and __fish_seen_subcommand_from list" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand nodes; and __fish_seen_subcommand_from list" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand nodes; and __fish_seen_subcommand_from list" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand nodes; and __fish_seen_subcommand_from list" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand nodes; and __fish_seen_subcommand_from memory_breakdown_in_percent" -l node -d 'target node, must be a cluster member' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand nodes; and __fish_seen_subcommand_from memory_breakdown_in_percent" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand nodes; and __fish_seen_subcommand_from memory_breakdown_in_percent" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand nodes; and __fish_seen_subcommand_from memory_breakdown_in_percent" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand nodes; and __fish_seen_subcommand_from memory_breakdown_in_percent" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand nodes; and __fish_seen_subcommand_from memory_breakdown_in_bytes" -l node -d 'target node, must be a cluster member' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand nodes; and __fish_seen_subcommand_from memory_breakdown_in_bytes" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand nodes; and __fish_seen_subcommand_from memory_breakdown_in_bytes" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand nodes; and __fish_seen_subcommand_from memory_breakdown_in_bytes" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand nodes; and __fish_seen_subcommand_from memory_breakdown_in_bytes" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand nodes; and __fish_seen_subcommand_from help" -f -a "list"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand nodes; and __fish_seen_subcommand_from help" -f -a "memory_breakdown_in_percent" -d 'Provides a memory footprint breakdown (in percent) for the target node'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand nodes; and __fish_seen_subcommand_from help" -f -a "memory_breakdown_in_bytes" -d 'Provides a memory footprint breakdown (in bytes) for the target node'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand nodes; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and not __fish_seen_subcommand_from declare update set delete delete_definition_keys delete_definition_keys_from_all_in list list_in list_matching_object patch update_definition update_definitions_of_all_in help" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and not __fish_seen_subcommand_from declare update set delete delete_definition_keys delete_definition_keys_from_all_in list list_in list_matching_object patch update_definition update_definitions_of_all_in help" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and not __fish_seen_subcommand_from declare update set delete delete_definition_keys delete_definition_keys_from_all_in list list_in list_matching_object patch update_definition update_definitions_of_all_in help" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and not __fish_seen_subcommand_from declare update set delete delete_definition_keys delete_definition_keys_from_all_in list list_in list_matching_object patch update_definition update_definitions_of_all_in help" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and not __fish_seen_subcommand_from declare update set delete delete_definition_keys delete_definition_keys_from_all_in list list_in list_matching_object patch update_definition update_definitions_of_all_in help" -f -a "declare" -d 'Creates or updates an operator policy'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and not __fish_seen_subcommand_from declare update set delete delete_definition_keys delete_definition_keys_from_all_in list list_in list_matching_object patch update_definition update_definitions_of_all_in help" -f -a "update" -d 'Creates or updates an operator policy'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and not __fish_seen_subcommand_from declare update set delete delete_definition_keys delete_definition_keys_from_all_in list list_in list_matching_object patch update_definition update_definitions_of_all_in help" -f -a "set" -d 'Creates or updates an operator policy'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and not __fish_seen_subcommand_from declare update set delete delete_definition_keys delete_definition_keys_from_all_in list list_in list_matching_object patch update_definition update_definitions_of_all_in help" -f -a "delete" -d 'Deletes an operator policy'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and not __fish_seen_subcommand_from declare update set delete delete_definition_keys delete_definition_keys_from_all_in list list_in list_matching_object patch update_definition update_definitions_of_all_in help" -f -a "delete_definition_keys" -d 'Deletes definition keys from an operator policy, unless it is the only key'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and not __fish_seen_subcommand_from declare update set delete delete_definition_keys delete_definition_keys_from_all_in list list_in list_matching_object patch update_definition update_definitions_of_all_in help" -f -a "delete_definition_keys_from_all_in" -d 'Deletes a definition key from all operator policies in a virtual host, unless it is the only key'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and not __fish_seen_subcommand_from declare update set delete delete_definition_keys delete_definition_keys_from_all_in list list_in list_matching_object patch update_definition update_definitions_of_all_in help" -f -a "list"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and not __fish_seen_subcommand_from declare update set delete delete_definition_keys delete_definition_keys_from_all_in list list_in list_matching_object patch update_definition update_definitions_of_all_in help" -f -a "list_in" -d 'Lists operator policies in a specific virtual host'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and not __fish_seen_subcommand_from declare update set delete delete_definition_keys delete_definition_keys_from_all_in list list_in list_matching_object patch update_definition update_definitions_of_all_in help" -f -a "list_matching_object" -d 'Lists operator policies that match an object (queue, stream, exchange) name'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and not __fish_seen_subcommand_from declare update set delete delete_definition_keys delete_definition_keys_from_all_in list list_in list_matching_object patch update_definition update_definitions_of_all_in help" -f -a "patch" -d 'Merges a set of keys into existing operator policy definitions'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and not __fish_seen_subcommand_from declare update set delete delete_definition_keys delete_definition_keys_from_all_in list list_in list_matching_object patch update_definition update_definitions_of_all_in help" -f -a "update_definition" -d 'Updates an operator policy definition key'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and not __fish_seen_subcommand_from declare update set delete delete_definition_keys delete_definition_keys_from_all_in list list_in list_matching_object patch update_definition update_definitions_of_all_in help" -f -a "update_definitions_of_all_in" -d 'Updates a definition key in all operator policies in a virtual host'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and not __fish_seen_subcommand_from declare update set delete delete_definition_keys delete_definition_keys_from_all_in list list_in list_matching_object patch update_definition update_definitions_of_all_in help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from declare" -l name -d 'operator policy name' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from declare" -l pattern -d 'the pattern that is used to match entity (queue, stream, exchange) names' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from declare" -l apply-to -d 'entities to apply to (queues, classic_queues, quorum_queues, streams, exchanges, all)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from declare" -l priority -d 'operator policy priority (only the policy with the highest priority is effective)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from declare" -l definition -d 'operator policy definition' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from declare" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from declare" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from declare" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from declare" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from update" -l name -d 'operator policy name' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from update" -l pattern -d 'the pattern that is used to match entity (queue, stream, exchange) names' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from update" -l apply-to -d 'entities to apply to (queues, classic_queues, quorum_queues, streams, exchanges, all)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from update" -l priority -d 'operator policy priority (only the policy with the highest priority is effective)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from update" -l definition -d 'operator policy definition' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from update" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from update" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from update" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from update" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from set" -l name -d 'operator policy name' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from set" -l pattern -d 'the pattern that is used to match entity (queue, stream, exchange) names' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from set" -l apply-to -d 'entities to apply to (queues, classic_queues, quorum_queues, streams, exchanges, all)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from set" -l priority -d 'operator policy priority (only the policy with the highest priority is effective)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from set" -l definition -d 'operator policy definition' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from set" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from set" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from set" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from set" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from delete" -l name -d 'policy name' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from delete" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from delete" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from delete" -l idempotently -d 'do not consider 404 Not Found API responses to be errors'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from delete" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from delete" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from delete_definition_keys" -l name -d 'operator policy name' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from delete_definition_keys" -l definition-keys -d 'comma-separated definition keys' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from delete_definition_keys" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from delete_definition_keys" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from delete_definition_keys" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from delete_definition_keys" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from delete_definition_keys_from_all_in" -l definition-keys -d 'comma-separated definition keys' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from delete_definition_keys_from_all_in" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from delete_definition_keys_from_all_in" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from delete_definition_keys_from_all_in" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from delete_definition_keys_from_all_in" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from list" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from list" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from list" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from list" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from list_in" -l apply-to -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from list_in" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from list_in" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from list_in" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from list_in" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from list_matching_object" -l name -d 'name to verify' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from list_matching_object" -l type -d 'target type, one of \'queues\', \'streams\', \'exchanges\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from list_matching_object" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from list_matching_object" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from list_matching_object" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from list_matching_object" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from patch" -l name -d 'operator policy name' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from patch" -l definition -d 'operator policy definition changes to merge into the existing ones' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from patch" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from patch" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from patch" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from patch" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from update_definition" -l name -d 'operator policy name' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from update_definition" -l definition-key -d 'operator policy definition key to update' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from update_definition" -l new-value -d 'new definition value to set' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from update_definition" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from update_definition" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from update_definition" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from update_definition" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from update_definitions_of_all_in" -l definition-key -d 'operator policy definition key to update' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from update_definitions_of_all_in" -l new-value -d 'new operator definition value to set' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from update_definitions_of_all_in" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from update_definitions_of_all_in" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from update_definitions_of_all_in" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from update_definitions_of_all_in" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from help" -f -a "declare" -d 'Creates or updates an operator policy'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from help" -f -a "delete" -d 'Deletes an operator policy'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from help" -f -a "delete_definition_keys" -d 'Deletes definition keys from an operator policy, unless it is the only key'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from help" -f -a "delete_definition_keys_from_all_in" -d 'Deletes a definition key from all operator policies in a virtual host, unless it is the only key'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from help" -f -a "list"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from help" -f -a "list_in" -d 'Lists operator policies in a specific virtual host'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from help" -f -a "list_matching_object" -d 'Lists operator policies that match an object (queue, stream, exchange) name'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from help" -f -a "patch" -d 'Merges a set of keys into existing operator policy definitions'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from help" -f -a "update_definition" -d 'Updates an operator policy definition key'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from help" -f -a "update_definitions_of_all_in" -d 'Updates a definition key in all operator policies in a virtual host'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand operator_policies; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand parameters; and not __fish_seen_subcommand_from clear list_all list list_in set help" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand parameters; and not __fish_seen_subcommand_from clear list_all list list_in set help" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand parameters; and not __fish_seen_subcommand_from clear list_all list list_in set help" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand parameters; and not __fish_seen_subcommand_from clear list_all list list_in set help" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand parameters; and not __fish_seen_subcommand_from clear list_all list list_in set help" -f -a "clear" -d 'Clears (deletes) a runtime parameter'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand parameters; and not __fish_seen_subcommand_from clear list_all list list_in set help" -f -a "list_all"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand parameters; and not __fish_seen_subcommand_from clear list_all list list_in set help" -f -a "list"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand parameters; and not __fish_seen_subcommand_from clear list_all list list_in set help" -f -a "list_in"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand parameters; and not __fish_seen_subcommand_from clear list_all list list_in set help" -f -a "set" -d 'Sets a runtime parameter'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand parameters; and not __fish_seen_subcommand_from clear list_all list list_in set help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand parameters; and __fish_seen_subcommand_from clear" -l name -d 'parameter\'s name' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand parameters; and __fish_seen_subcommand_from clear" -l component -d 'component (eg. federation-upstream)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand parameters; and __fish_seen_subcommand_from clear" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand parameters; and __fish_seen_subcommand_from clear" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand parameters; and __fish_seen_subcommand_from clear" -l idempotently -d 'do not consider 404 Not Found API responses to be errors'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand parameters; and __fish_seen_subcommand_from clear" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand parameters; and __fish_seen_subcommand_from clear" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand parameters; and __fish_seen_subcommand_from list_all" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand parameters; and __fish_seen_subcommand_from list_all" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand parameters; and __fish_seen_subcommand_from list_all" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand parameters; and __fish_seen_subcommand_from list_all" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand parameters; and __fish_seen_subcommand_from list" -l component -d 'component (for example: federation-upstream, vhost-limits)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand parameters; and __fish_seen_subcommand_from list" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand parameters; and __fish_seen_subcommand_from list" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand parameters; and __fish_seen_subcommand_from list" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand parameters; and __fish_seen_subcommand_from list" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand parameters; and __fish_seen_subcommand_from list_in" -l component -d 'component (for example: federation-upstream, vhost-limits)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand parameters; and __fish_seen_subcommand_from list_in" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand parameters; and __fish_seen_subcommand_from list_in" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand parameters; and __fish_seen_subcommand_from list_in" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand parameters; and __fish_seen_subcommand_from list_in" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand parameters; and __fish_seen_subcommand_from set" -l name -d 'parameter\'s name' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand parameters; and __fish_seen_subcommand_from set" -l component -d 'component (eg. federation)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand parameters; and __fish_seen_subcommand_from set" -l value -d 'parameter\'s value' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand parameters; and __fish_seen_subcommand_from set" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand parameters; and __fish_seen_subcommand_from set" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand parameters; and __fish_seen_subcommand_from set" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand parameters; and __fish_seen_subcommand_from set" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand parameters; and __fish_seen_subcommand_from help" -f -a "clear" -d 'Clears (deletes) a runtime parameter'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand parameters; and __fish_seen_subcommand_from help" -f -a "list_all"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand parameters; and __fish_seen_subcommand_from help" -f -a "list"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand parameters; and __fish_seen_subcommand_from help" -f -a "list_in"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand parameters; and __fish_seen_subcommand_from help" -f -a "set" -d 'Sets a runtime parameter'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand parameters; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand passwords; and not __fish_seen_subcommand_from salt_and_hash help" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand passwords; and not __fish_seen_subcommand_from salt_and_hash help" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand passwords; and not __fish_seen_subcommand_from salt_and_hash help" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand passwords; and not __fish_seen_subcommand_from salt_and_hash help" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand passwords; and not __fish_seen_subcommand_from salt_and_hash help" -f -a "salt_and_hash"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand passwords; and not __fish_seen_subcommand_from salt_and_hash help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand passwords; and __fish_seen_subcommand_from salt_and_hash" -l hashing-algorithm -d 'The hashing algorithm to use: SHA256 or SHA512' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand passwords; and __fish_seen_subcommand_from salt_and_hash" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand passwords; and __fish_seen_subcommand_from salt_and_hash" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand passwords; and __fish_seen_subcommand_from salt_and_hash" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand passwords; and __fish_seen_subcommand_from salt_and_hash" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand passwords; and __fish_seen_subcommand_from help" -f -a "salt_and_hash"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand passwords; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand permissions; and not __fish_seen_subcommand_from list declare delete help" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand permissions; and not __fish_seen_subcommand_from list declare delete help" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand permissions; and not __fish_seen_subcommand_from list declare delete help" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand permissions; and not __fish_seen_subcommand_from list declare delete help" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand permissions; and not __fish_seen_subcommand_from list declare delete help" -f -a "list"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand permissions; and not __fish_seen_subcommand_from list declare delete help" -f -a "declare" -d 'grants permissions to a user'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand permissions; and not __fish_seen_subcommand_from list declare delete help" -f -a "delete" -d 'Revokes user permissions to a given vhost'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand permissions; and not __fish_seen_subcommand_from list declare delete help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand permissions; and __fish_seen_subcommand_from list" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand permissions; and __fish_seen_subcommand_from list" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand permissions; and __fish_seen_subcommand_from list" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand permissions; and __fish_seen_subcommand_from list" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand permissions; and __fish_seen_subcommand_from declare" -l username -d 'username' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand permissions; and __fish_seen_subcommand_from declare" -l configure -d 'name pattern for configuration access' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand permissions; and __fish_seen_subcommand_from declare" -l read -d 'name pattern for read access' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand permissions; and __fish_seen_subcommand_from declare" -l write -d 'name pattern for write access' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand permissions; and __fish_seen_subcommand_from declare" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand permissions; and __fish_seen_subcommand_from declare" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand permissions; and __fish_seen_subcommand_from declare" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand permissions; and __fish_seen_subcommand_from declare" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand permissions; and __fish_seen_subcommand_from delete" -l username -d 'username' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand permissions; and __fish_seen_subcommand_from delete" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand permissions; and __fish_seen_subcommand_from delete" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand permissions; and __fish_seen_subcommand_from delete" -l idempotently -d 'do not consider 404 Not Found API responses to be errors'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand permissions; and __fish_seen_subcommand_from delete" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand permissions; and __fish_seen_subcommand_from delete" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand permissions; and __fish_seen_subcommand_from help" -f -a "list"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand permissions; and __fish_seen_subcommand_from help" -f -a "declare" -d 'grants permissions to a user'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand permissions; and __fish_seen_subcommand_from help" -f -a "delete" -d 'Revokes user permissions to a given vhost'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand permissions; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand plugins; and not __fish_seen_subcommand_from list_all list_on_node help" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand plugins; and not __fish_seen_subcommand_from list_all list_on_node help" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand plugins; and not __fish_seen_subcommand_from list_all list_on_node help" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand plugins; and not __fish_seen_subcommand_from list_all list_on_node help" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand plugins; and not __fish_seen_subcommand_from list_all list_on_node help" -f -a "list_all" -d 'Lists plugins across all cluster nodes'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand plugins; and not __fish_seen_subcommand_from list_all list_on_node help" -f -a "list_on_node" -d 'Lists plugins enabled on a specific node'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand plugins; and not __fish_seen_subcommand_from list_all list_on_node help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand plugins; and __fish_seen_subcommand_from list_all" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand plugins; and __fish_seen_subcommand_from list_all" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand plugins; and __fish_seen_subcommand_from list_all" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand plugins; and __fish_seen_subcommand_from list_all" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand plugins; and __fish_seen_subcommand_from list_on_node" -l node -d 'target node, must be a cluster member' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand plugins; and __fish_seen_subcommand_from list_on_node" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand plugins; and __fish_seen_subcommand_from list_on_node" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand plugins; and __fish_seen_subcommand_from list_on_node" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand plugins; and __fish_seen_subcommand_from list_on_node" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand plugins; and __fish_seen_subcommand_from help" -f -a "list_all" -d 'Lists plugins across all cluster nodes'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand plugins; and __fish_seen_subcommand_from help" -f -a "list_on_node" -d 'Lists plugins enabled on a specific node'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand plugins; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and not __fish_seen_subcommand_from declare update set declare_override declare_blanket delete delete_definition_keys delete_definition_keys_from_all delete_definition_keys_from_all_in list list_conflicting list_conflicting_in list_in list_matching_object patch update_definition update_definitions_of_all update_definitions_of_all_in help" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and not __fish_seen_subcommand_from declare update set declare_override declare_blanket delete delete_definition_keys delete_definition_keys_from_all delete_definition_keys_from_all_in list list_conflicting list_conflicting_in list_in list_matching_object patch update_definition update_definitions_of_all update_definitions_of_all_in help" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and not __fish_seen_subcommand_from declare update set declare_override declare_blanket delete delete_definition_keys delete_definition_keys_from_all delete_definition_keys_from_all_in list list_conflicting list_conflicting_in list_in list_matching_object patch update_definition update_definitions_of_all update_definitions_of_all_in help" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and not __fish_seen_subcommand_from declare update set declare_override declare_blanket delete delete_definition_keys delete_definition_keys_from_all delete_definition_keys_from_all_in list list_conflicting list_conflicting_in list_in list_matching_object patch update_definition update_definitions_of_all update_definitions_of_all_in help" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and not __fish_seen_subcommand_from declare update set declare_override declare_blanket delete delete_definition_keys delete_definition_keys_from_all delete_definition_keys_from_all_in list list_conflicting list_conflicting_in list_in list_matching_object patch update_definition update_definitions_of_all update_definitions_of_all_in help" -f -a "declare" -d 'Creates or updates a policy'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and not __fish_seen_subcommand_from declare update set declare_override declare_blanket delete delete_definition_keys delete_definition_keys_from_all delete_definition_keys_from_all_in list list_conflicting list_conflicting_in list_in list_matching_object patch update_definition update_definitions_of_all update_definitions_of_all_in help" -f -a "update" -d 'Creates or updates a policy'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and not __fish_seen_subcommand_from declare update set declare_override declare_blanket delete delete_definition_keys delete_definition_keys_from_all delete_definition_keys_from_all_in list list_conflicting list_conflicting_in list_in list_matching_object patch update_definition update_definitions_of_all update_definitions_of_all_in help" -f -a "set" -d 'Creates or updates a policy'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and not __fish_seen_subcommand_from declare update set declare_override declare_blanket delete delete_definition_keys delete_definition_keys_from_all delete_definition_keys_from_all_in list list_conflicting list_conflicting_in list_in list_matching_object patch update_definition update_definitions_of_all update_definitions_of_all_in help" -f -a "declare_override" -d 'Declares a new policy from an existing one, with a higher priority, and merges a set of keys into the new overriding policy definition'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and not __fish_seen_subcommand_from declare update set declare_override declare_blanket delete delete_definition_keys delete_definition_keys_from_all delete_definition_keys_from_all_in list list_conflicting list_conflicting_in list_in list_matching_object patch update_definition update_definitions_of_all update_definitions_of_all_in help" -f -a "declare_blanket" -d 'Creates a low priority blanket policy, a policy that matches all objects not matched by any other policy'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and not __fish_seen_subcommand_from declare update set declare_override declare_blanket delete delete_definition_keys delete_definition_keys_from_all delete_definition_keys_from_all_in list list_conflicting list_conflicting_in list_in list_matching_object patch update_definition update_definitions_of_all update_definitions_of_all_in help" -f -a "delete" -d 'Deletes a policy'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and not __fish_seen_subcommand_from declare update set declare_override declare_blanket delete delete_definition_keys delete_definition_keys_from_all delete_definition_keys_from_all_in list list_conflicting list_conflicting_in list_in list_matching_object patch update_definition update_definitions_of_all update_definitions_of_all_in help" -f -a "delete_definition_keys" -d 'Deletes a definition key from a policy, unless it is the only key'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and not __fish_seen_subcommand_from declare update set declare_override declare_blanket delete delete_definition_keys delete_definition_keys_from_all delete_definition_keys_from_all_in list list_conflicting list_conflicting_in list_in list_matching_object patch update_definition update_definitions_of_all update_definitions_of_all_in help" -f -a "delete_definition_keys_from_all" -d 'Deletes definition keys from all policies in the cluster, unless it is the only policy key'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and not __fish_seen_subcommand_from declare update set declare_override declare_blanket delete delete_definition_keys delete_definition_keys_from_all delete_definition_keys_from_all_in list list_conflicting list_conflicting_in list_in list_matching_object patch update_definition update_definitions_of_all update_definitions_of_all_in help" -f -a "delete_definition_keys_from_all_in" -d 'Deletes definition keys from all policies in a virtual host, unless it is the only policy key'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and not __fish_seen_subcommand_from declare update set declare_override declare_blanket delete delete_definition_keys delete_definition_keys_from_all delete_definition_keys_from_all_in list list_conflicting list_conflicting_in list_in list_matching_object patch update_definition update_definitions_of_all update_definitions_of_all_in help" -f -a "list"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and not __fish_seen_subcommand_from declare update set declare_override declare_blanket delete delete_definition_keys delete_definition_keys_from_all delete_definition_keys_from_all_in list list_conflicting list_conflicting_in list_in list_matching_object patch update_definition update_definitions_of_all update_definitions_of_all_in help" -f -a "list_conflicting" -d 'Lists policies that have conflicting priorities across all virtual hosts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and not __fish_seen_subcommand_from declare update set declare_override declare_blanket delete delete_definition_keys delete_definition_keys_from_all delete_definition_keys_from_all_in list list_conflicting list_conflicting_in list_in list_matching_object patch update_definition update_definitions_of_all update_definitions_of_all_in help" -f -a "list_conflicting_in" -d 'Lists policies that have conflicting priorities in a specific virtual host'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and not __fish_seen_subcommand_from declare update set declare_override declare_blanket delete delete_definition_keys delete_definition_keys_from_all delete_definition_keys_from_all_in list list_conflicting list_conflicting_in list_in list_matching_object patch update_definition update_definitions_of_all update_definitions_of_all_in help" -f -a "list_in" -d 'Lists policies in a specific virtual host'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and not __fish_seen_subcommand_from declare update set declare_override declare_blanket delete delete_definition_keys delete_definition_keys_from_all delete_definition_keys_from_all_in list list_conflicting list_conflicting_in list_in list_matching_object patch update_definition update_definitions_of_all update_definitions_of_all_in help" -f -a "list_matching_object" -d 'Lists policies that match an object (queue, stream, exchange) name'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and not __fish_seen_subcommand_from declare update set declare_override declare_blanket delete delete_definition_keys delete_definition_keys_from_all delete_definition_keys_from_all_in list list_conflicting list_conflicting_in list_in list_matching_object patch update_definition update_definitions_of_all update_definitions_of_all_in help" -f -a "patch" -d 'Merges a set of keys into existing policy definitions'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and not __fish_seen_subcommand_from declare update set declare_override declare_blanket delete delete_definition_keys delete_definition_keys_from_all delete_definition_keys_from_all_in list list_conflicting list_conflicting_in list_in list_matching_object patch update_definition update_definitions_of_all update_definitions_of_all_in help" -f -a "update_definition" -d 'Updates a policy definition key'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and not __fish_seen_subcommand_from declare update set declare_override declare_blanket delete delete_definition_keys delete_definition_keys_from_all delete_definition_keys_from_all_in list list_conflicting list_conflicting_in list_in list_matching_object patch update_definition update_definitions_of_all update_definitions_of_all_in help" -f -a "update_definitions_of_all" -d 'Updates a definition key in all policies in the cluster'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and not __fish_seen_subcommand_from declare update set declare_override declare_blanket delete delete_definition_keys delete_definition_keys_from_all delete_definition_keys_from_all_in list list_conflicting list_conflicting_in list_in list_matching_object patch update_definition update_definitions_of_all update_definitions_of_all_in help" -f -a "update_definitions_of_all_in" -d 'Updates a definition key in all policies in a virtual host'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and not __fish_seen_subcommand_from declare update set declare_override declare_blanket delete delete_definition_keys delete_definition_keys_from_all delete_definition_keys_from_all_in list list_conflicting list_conflicting_in list_in list_matching_object patch update_definition update_definitions_of_all update_definitions_of_all_in help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from declare" -l name -d 'policy name' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from declare" -l pattern -d 'the pattern that is used to match entity (queue, stream, exchange) names' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from declare" -l apply-to -d 'entities to apply to (queues, classic_queues, quorum_queues, streams, exchanges, all)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from declare" -l priority -d 'policy priority (only the policy with the highest priority is effective)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from declare" -l definition -d 'policy definition' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from declare" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from declare" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from declare" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from declare" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from update" -l name -d 'policy name' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from update" -l pattern -d 'the pattern that is used to match entity (queue, stream, exchange) names' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from update" -l apply-to -d 'entities to apply to (queues, classic_queues, quorum_queues, streams, exchanges, all)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from update" -l priority -d 'policy priority (only the policy with the highest priority is effective)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from update" -l definition -d 'policy definition' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from update" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from update" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from update" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from update" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from set" -l name -d 'policy name' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from set" -l pattern -d 'the pattern that is used to match entity (queue, stream, exchange) names' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from set" -l apply-to -d 'entities to apply to (queues, classic_queues, quorum_queues, streams, exchanges, all)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from set" -l priority -d 'policy priority (only the policy with the highest priority is effective)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from set" -l definition -d 'policy definition' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from set" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from set" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from set" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from set" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from declare_override" -l name -d 'the name of the policy to create an override for' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from declare_override" -l override-name -d 'the name of the new overriding policy. If omitted, an \'override\' suffix will be added to the original name.' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from declare_override" -l definition -d 'additional definitions to merge into the new overriding policy' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from declare_override" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from declare_override" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from declare_override" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from declare_override" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from declare_blanket" -l name -d 'blanket policy name' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from declare_blanket" -l apply-to -d 'entities to apply to (queues, classic_queues, quorum_queues, streams, exchanges, all)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from declare_blanket" -l definition -d 'policy definition' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from declare_blanket" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from declare_blanket" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from declare_blanket" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from declare_blanket" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from delete" -l name -d 'policy name' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from delete" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from delete" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from delete" -l idempotently -d 'do not consider 404 Not Found API responses to be errors'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from delete" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from delete" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from delete_definition_keys" -l name -d 'policy name' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from delete_definition_keys" -l definition-keys -d 'comma-separated definition keys' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from delete_definition_keys" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from delete_definition_keys" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from delete_definition_keys" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from delete_definition_keys" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from delete_definition_keys_from_all" -l definition-keys -d 'comma-separated definition keys' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from delete_definition_keys_from_all" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from delete_definition_keys_from_all" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from delete_definition_keys_from_all" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from delete_definition_keys_from_all" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from delete_definition_keys_from_all_in" -l definition-keys -d 'comma-separated definition keys' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from delete_definition_keys_from_all_in" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from delete_definition_keys_from_all_in" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from delete_definition_keys_from_all_in" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from delete_definition_keys_from_all_in" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from list" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from list" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from list" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from list" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from list_conflicting" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from list_conflicting" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from list_conflicting" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from list_conflicting" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from list_conflicting_in" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from list_conflicting_in" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from list_conflicting_in" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from list_conflicting_in" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from list_in" -l apply-to -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from list_in" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from list_in" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from list_in" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from list_in" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from list_matching_object" -l name -d 'name to verify' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from list_matching_object" -l type -d 'target type, one of \'queues\', \'streams\', \'exchanges\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from list_matching_object" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from list_matching_object" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from list_matching_object" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from list_matching_object" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from patch" -l name -d 'policy name' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from patch" -l definition -d 'policy definition changes to merge into the existing ones' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from patch" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from patch" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from patch" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from patch" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from update_definition" -l name -d 'policy name' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from update_definition" -l definition-key -d 'policy definition key to update' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from update_definition" -l new-value -d 'new definition value to set' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from update_definition" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from update_definition" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from update_definition" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from update_definition" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from update_definitions_of_all" -l definition-key -d 'policy definition key to update' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from update_definitions_of_all" -l new-value -d 'new definition value to set' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from update_definitions_of_all" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from update_definitions_of_all" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from update_definitions_of_all" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from update_definitions_of_all" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from update_definitions_of_all_in" -l definition-key -d 'policy definition key to update' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from update_definitions_of_all_in" -l new-value -d 'new definition value to set' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from update_definitions_of_all_in" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from update_definitions_of_all_in" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from update_definitions_of_all_in" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from update_definitions_of_all_in" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from help" -f -a "declare" -d 'Creates or updates a policy'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from help" -f -a "declare_override" -d 'Declares a new policy from an existing one, with a higher priority, and merges a set of keys into the new overriding policy definition'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from help" -f -a "declare_blanket" -d 'Creates a low priority blanket policy, a policy that matches all objects not matched by any other policy'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from help" -f -a "delete" -d 'Deletes a policy'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from help" -f -a "delete_definition_keys" -d 'Deletes a definition key from a policy, unless it is the only key'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from help" -f -a "delete_definition_keys_from_all" -d 'Deletes definition keys from all policies in the cluster, unless it is the only policy key'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from help" -f -a "delete_definition_keys_from_all_in" -d 'Deletes definition keys from all policies in a virtual host, unless it is the only policy key'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from help" -f -a "list"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from help" -f -a "list_conflicting" -d 'Lists policies that have conflicting priorities across all virtual hosts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from help" -f -a "list_conflicting_in" -d 'Lists policies that have conflicting priorities in a specific virtual host'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from help" -f -a "list_in" -d 'Lists policies in a specific virtual host'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from help" -f -a "list_matching_object" -d 'Lists policies that match an object (queue, stream, exchange) name'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from help" -f -a "patch" -d 'Merges a set of keys into existing policy definitions'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from help" -f -a "update_definition" -d 'Updates a policy definition key'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from help" -f -a "update_definitions_of_all" -d 'Updates a definition key in all policies in the cluster'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from help" -f -a "update_definitions_of_all_in" -d 'Updates a definition key in all policies in a virtual host'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand policies; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand publish; and not __fish_seen_subcommand_from message help" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand publish; and not __fish_seen_subcommand_from message help" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand publish; and not __fish_seen_subcommand_from message help" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand publish; and not __fish_seen_subcommand_from message help" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand publish; and not __fish_seen_subcommand_from message help" -f -a "message" -d 'Publishes (inefficiently) message(s) to a queue or a stream. Only suitable for development and test environments. Prefer messaging or streaming protocol clients!'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand publish; and not __fish_seen_subcommand_from message help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand publish; and __fish_seen_subcommand_from message" -s k -l routing-key -d 'Name of virtual host' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand publish; and __fish_seen_subcommand_from message" -s e -l exchange -d 'Exchange name (defaults to empty)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand publish; and __fish_seen_subcommand_from message" -s m -l payload -d 'Message payload/body' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand publish; and __fish_seen_subcommand_from message" -s p -l properties -d 'Message properties' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand publish; and __fish_seen_subcommand_from message" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand publish; and __fish_seen_subcommand_from message" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand publish; and __fish_seen_subcommand_from message" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand publish; and __fish_seen_subcommand_from message" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand publish; and __fish_seen_subcommand_from help" -f -a "message" -d 'Publishes (inefficiently) message(s) to a queue or a stream. Only suitable for development and test environments. Prefer messaging or streaming protocol clients!'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand publish; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand purge; and not __fish_seen_subcommand_from queue help" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand purge; and not __fish_seen_subcommand_from queue help" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand purge; and not __fish_seen_subcommand_from queue help" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand purge; and not __fish_seen_subcommand_from queue help" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand purge; and not __fish_seen_subcommand_from queue help" -f -a "queue"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand purge; and not __fish_seen_subcommand_from queue help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand purge; and __fish_seen_subcommand_from queue" -l name -d 'name of the queue to purge' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand purge; and __fish_seen_subcommand_from queue" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand purge; and __fish_seen_subcommand_from queue" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand purge; and __fish_seen_subcommand_from queue" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand purge; and __fish_seen_subcommand_from queue" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand purge; and __fish_seen_subcommand_from help" -f -a "queue"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand purge; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand queues; and not __fish_seen_subcommand_from declare delete list purge rebalance show help" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand queues; and not __fish_seen_subcommand_from declare delete list purge rebalance show help" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand queues; and not __fish_seen_subcommand_from declare delete list purge rebalance show help" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand queues; and not __fish_seen_subcommand_from declare delete list purge rebalance show help" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand queues; and not __fish_seen_subcommand_from declare delete list purge rebalance show help" -f -a "declare" -d 'Declares a queue or a stream'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand queues; and not __fish_seen_subcommand_from declare delete list purge rebalance show help" -f -a "delete" -d 'Deletes a queue'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand queues; and not __fish_seen_subcommand_from declare delete list purge rebalance show help" -f -a "list"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand queues; and not __fish_seen_subcommand_from declare delete list purge rebalance show help" -f -a "purge"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand queues; and not __fish_seen_subcommand_from declare delete list purge rebalance show help" -f -a "rebalance" -d 'Rebalances queue leaders'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand queues; and not __fish_seen_subcommand_from declare delete list purge rebalance show help" -f -a "show" -d 'Shows details for a single queue'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand queues; and not __fish_seen_subcommand_from declare delete list purge rebalance show help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand queues; and __fish_seen_subcommand_from declare" -l name -d 'name' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand queues; and __fish_seen_subcommand_from declare" -l type -d 'queue type' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand queues; and __fish_seen_subcommand_from declare" -l durable -d 'should it persist after a restart' -r -f -a "true\t''
false\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand queues; and __fish_seen_subcommand_from declare" -l auto-delete -d 'should it be deleted when the last consumer disconnects' -r -f -a "true\t''
false\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand queues; and __fish_seen_subcommand_from declare" -l arguments -d 'additional queue arguments' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand queues; and __fish_seen_subcommand_from declare" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand queues; and __fish_seen_subcommand_from declare" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand queues; and __fish_seen_subcommand_from declare" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand queues; and __fish_seen_subcommand_from declare" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand queues; and __fish_seen_subcommand_from delete" -l name -d 'queue name' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand queues; and __fish_seen_subcommand_from delete" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand queues; and __fish_seen_subcommand_from delete" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand queues; and __fish_seen_subcommand_from delete" -l idempotently -d 'do not consider 404 Not Found API responses to be errors'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand queues; and __fish_seen_subcommand_from delete" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand queues; and __fish_seen_subcommand_from delete" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand queues; and __fish_seen_subcommand_from list" -l page -d 'page number (1-indexed)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand queues; and __fish_seen_subcommand_from list" -l page-size -d 'number of results per page (default: 100, max: 500)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand queues; and __fish_seen_subcommand_from list" -l columns -d 'comma-separated list of columns to display' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand queues; and __fish_seen_subcommand_from list" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand queues; and __fish_seen_subcommand_from list" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand queues; and __fish_seen_subcommand_from list" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand queues; and __fish_seen_subcommand_from list" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand queues; and __fish_seen_subcommand_from purge" -l name -d 'name of the queue to purge' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand queues; and __fish_seen_subcommand_from purge" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand queues; and __fish_seen_subcommand_from purge" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand queues; and __fish_seen_subcommand_from purge" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand queues; and __fish_seen_subcommand_from purge" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand queues; and __fish_seen_subcommand_from rebalance" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand queues; and __fish_seen_subcommand_from rebalance" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand queues; and __fish_seen_subcommand_from rebalance" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand queues; and __fish_seen_subcommand_from rebalance" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand queues; and __fish_seen_subcommand_from show" -l name -d 'queue name' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand queues; and __fish_seen_subcommand_from show" -l columns -d 'comma-separated list of columns to display' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand queues; and __fish_seen_subcommand_from show" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand queues; and __fish_seen_subcommand_from show" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand queues; and __fish_seen_subcommand_from show" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand queues; and __fish_seen_subcommand_from show" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand queues; and __fish_seen_subcommand_from help" -f -a "declare" -d 'Declares a queue or a stream'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand queues; and __fish_seen_subcommand_from help" -f -a "delete" -d 'Deletes a queue'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand queues; and __fish_seen_subcommand_from help" -f -a "list"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand queues; and __fish_seen_subcommand_from help" -f -a "purge"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand queues; and __fish_seen_subcommand_from help" -f -a "rebalance" -d 'Rebalances queue leaders'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand queues; and __fish_seen_subcommand_from help" -f -a "show" -d 'Shows details for a single queue'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand queues; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand rebalance; and not __fish_seen_subcommand_from queues help" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand rebalance; and not __fish_seen_subcommand_from queues help" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand rebalance; and not __fish_seen_subcommand_from queues help" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand rebalance; and not __fish_seen_subcommand_from queues help" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand rebalance; and not __fish_seen_subcommand_from queues help" -f -a "queues" -d 'Rebalances queue leaders'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand rebalance; and not __fish_seen_subcommand_from queues help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand rebalance; and __fish_seen_subcommand_from queues" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand rebalance; and __fish_seen_subcommand_from queues" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand rebalance; and __fish_seen_subcommand_from queues" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand rebalance; and __fish_seen_subcommand_from queues" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand rebalance; and __fish_seen_subcommand_from help" -f -a "queues" -d 'Rebalances queue leaders'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand rebalance; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shell; and not __fish_seen_subcommand_from completions help" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shell; and not __fish_seen_subcommand_from completions help" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shell; and not __fish_seen_subcommand_from completions help" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shell; and not __fish_seen_subcommand_from completions help" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shell; and not __fish_seen_subcommand_from completions help" -f -a "completions" -d 'Generate shell completion scripts for the CLI'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shell; and not __fish_seen_subcommand_from completions help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shell; and __fish_seen_subcommand_from completions" -l shell -d 'Target shell (bash, zsh, fish, elvish, nushell)' -r -f -a "bash\t''
zsh\t''
fish\t''
elvish\t''
nushell\t''
powershell\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shell; and __fish_seen_subcommand_from completions" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shell; and __fish_seen_subcommand_from completions" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shell; and __fish_seen_subcommand_from completions" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shell; and __fish_seen_subcommand_from completions" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shell; and __fish_seen_subcommand_from help" -f -a "completions" -d 'Generate shell completion scripts for the CLI'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shell; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand show; and not __fish_seen_subcommand_from overview churn endpoint memory_breakdown_in_bytes memory_breakdown_in_percent help" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand show; and not __fish_seen_subcommand_from overview churn endpoint memory_breakdown_in_bytes memory_breakdown_in_percent help" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand show; and not __fish_seen_subcommand_from overview churn endpoint memory_breakdown_in_bytes memory_breakdown_in_percent help" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand show; and not __fish_seen_subcommand_from overview churn endpoint memory_breakdown_in_bytes memory_breakdown_in_percent help" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand show; and not __fish_seen_subcommand_from overview churn endpoint memory_breakdown_in_bytes memory_breakdown_in_percent help" -f -a "overview" -d 'Displays essential information about target node and its cluster'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand show; and not __fish_seen_subcommand_from overview churn endpoint memory_breakdown_in_bytes memory_breakdown_in_percent help" -f -a "churn" -d 'Displays object churn metrics'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand show; and not __fish_seen_subcommand_from overview churn endpoint memory_breakdown_in_bytes memory_breakdown_in_percent help" -f -a "endpoint" -d 'Displays the computed HTTP API endpoint URI. Use for troubleshooting only.'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand show; and not __fish_seen_subcommand_from overview churn endpoint memory_breakdown_in_bytes memory_breakdown_in_percent help" -f -a "memory_breakdown_in_bytes" -d 'Provides a memory footprint breakdown (in bytes) for the target node'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand show; and not __fish_seen_subcommand_from overview churn endpoint memory_breakdown_in_bytes memory_breakdown_in_percent help" -f -a "memory_breakdown_in_percent" -d 'Provides a memory footprint breakdown (in percent) for the target node'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand show; and not __fish_seen_subcommand_from overview churn endpoint memory_breakdown_in_bytes memory_breakdown_in_percent help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand show; and __fish_seen_subcommand_from overview" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand show; and __fish_seen_subcommand_from overview" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand show; and __fish_seen_subcommand_from overview" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand show; and __fish_seen_subcommand_from overview" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand show; and __fish_seen_subcommand_from churn" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand show; and __fish_seen_subcommand_from churn" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand show; and __fish_seen_subcommand_from churn" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand show; and __fish_seen_subcommand_from churn" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand show; and __fish_seen_subcommand_from endpoint" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand show; and __fish_seen_subcommand_from endpoint" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand show; and __fish_seen_subcommand_from endpoint" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand show; and __fish_seen_subcommand_from endpoint" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand show; and __fish_seen_subcommand_from memory_breakdown_in_bytes" -l node -d 'target node, must be a cluster member' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand show; and __fish_seen_subcommand_from memory_breakdown_in_bytes" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand show; and __fish_seen_subcommand_from memory_breakdown_in_bytes" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand show; and __fish_seen_subcommand_from memory_breakdown_in_bytes" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand show; and __fish_seen_subcommand_from memory_breakdown_in_bytes" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand show; and __fish_seen_subcommand_from memory_breakdown_in_percent" -l node -d 'target node, must be a cluster member' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand show; and __fish_seen_subcommand_from memory_breakdown_in_percent" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand show; and __fish_seen_subcommand_from memory_breakdown_in_percent" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand show; and __fish_seen_subcommand_from memory_breakdown_in_percent" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand show; and __fish_seen_subcommand_from memory_breakdown_in_percent" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand show; and __fish_seen_subcommand_from help" -f -a "overview" -d 'Displays essential information about target node and its cluster'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand show; and __fish_seen_subcommand_from help" -f -a "churn" -d 'Displays object churn metrics'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand show; and __fish_seen_subcommand_from help" -f -a "endpoint" -d 'Displays the computed HTTP API endpoint URI. Use for troubleshooting only.'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand show; and __fish_seen_subcommand_from help" -f -a "memory_breakdown_in_bytes" -d 'Provides a memory footprint breakdown (in bytes) for the target node'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand show; and __fish_seen_subcommand_from help" -f -a "memory_breakdown_in_percent" -d 'Provides a memory footprint breakdown (in percent) for the target node'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand show; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and not __fish_seen_subcommand_from list_all list declare_amqp091 declare_amqp10 delete disable_tls_peer_verification_for_all_source_uris disable_tls_peer_verification_for_all_destination_uris enable_tls_peer_verification_for_all_source_uris enable_tls_peer_verification_for_all_destination_uris help" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and not __fish_seen_subcommand_from list_all list declare_amqp091 declare_amqp10 delete disable_tls_peer_verification_for_all_source_uris disable_tls_peer_verification_for_all_destination_uris enable_tls_peer_verification_for_all_source_uris enable_tls_peer_verification_for_all_destination_uris help" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and not __fish_seen_subcommand_from list_all list declare_amqp091 declare_amqp10 delete disable_tls_peer_verification_for_all_source_uris disable_tls_peer_verification_for_all_destination_uris enable_tls_peer_verification_for_all_source_uris enable_tls_peer_verification_for_all_destination_uris help" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and not __fish_seen_subcommand_from list_all list declare_amqp091 declare_amqp10 delete disable_tls_peer_verification_for_all_source_uris disable_tls_peer_verification_for_all_destination_uris enable_tls_peer_verification_for_all_source_uris enable_tls_peer_verification_for_all_destination_uris help" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and not __fish_seen_subcommand_from list_all list declare_amqp091 declare_amqp10 delete disable_tls_peer_verification_for_all_source_uris disable_tls_peer_verification_for_all_destination_uris enable_tls_peer_verification_for_all_source_uris enable_tls_peer_verification_for_all_destination_uris help" -f -a "list_all"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and not __fish_seen_subcommand_from list_all list declare_amqp091 declare_amqp10 delete disable_tls_peer_verification_for_all_source_uris disable_tls_peer_verification_for_all_destination_uris enable_tls_peer_verification_for_all_source_uris enable_tls_peer_verification_for_all_destination_uris help" -f -a "list"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and not __fish_seen_subcommand_from list_all list declare_amqp091 declare_amqp10 delete disable_tls_peer_verification_for_all_source_uris disable_tls_peer_verification_for_all_destination_uris enable_tls_peer_verification_for_all_source_uris enable_tls_peer_verification_for_all_destination_uris help" -f -a "declare_amqp091"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and not __fish_seen_subcommand_from list_all list declare_amqp091 declare_amqp10 delete disable_tls_peer_verification_for_all_source_uris disable_tls_peer_verification_for_all_destination_uris enable_tls_peer_verification_for_all_source_uris enable_tls_peer_verification_for_all_destination_uris help" -f -a "declare_amqp10"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and not __fish_seen_subcommand_from list_all list declare_amqp091 declare_amqp10 delete disable_tls_peer_verification_for_all_source_uris disable_tls_peer_verification_for_all_destination_uris enable_tls_peer_verification_for_all_source_uris enable_tls_peer_verification_for_all_destination_uris help" -f -a "delete"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and not __fish_seen_subcommand_from list_all list declare_amqp091 declare_amqp10 delete disable_tls_peer_verification_for_all_source_uris disable_tls_peer_verification_for_all_destination_uris enable_tls_peer_verification_for_all_source_uris enable_tls_peer_verification_for_all_destination_uris help" -f -a "disable_tls_peer_verification_for_all_source_uris" -d 'Use only in case of emergency. Disables TLS peer verification for all shovels.'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and not __fish_seen_subcommand_from list_all list declare_amqp091 declare_amqp10 delete disable_tls_peer_verification_for_all_source_uris disable_tls_peer_verification_for_all_destination_uris enable_tls_peer_verification_for_all_source_uris enable_tls_peer_verification_for_all_destination_uris help" -f -a "disable_tls_peer_verification_for_all_destination_uris" -d 'Use only in case of emergency. Disables TLS peer verification for all shovel destination URIs.'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and not __fish_seen_subcommand_from list_all list declare_amqp091 declare_amqp10 delete disable_tls_peer_verification_for_all_source_uris disable_tls_peer_verification_for_all_destination_uris enable_tls_peer_verification_for_all_source_uris enable_tls_peer_verification_for_all_destination_uris help" -f -a "enable_tls_peer_verification_for_all_source_uris" -d 'Enables TLS peer verification for all shovel source URIs with provided [RabbitMQ node-local] certificate paths.'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and not __fish_seen_subcommand_from list_all list declare_amqp091 declare_amqp10 delete disable_tls_peer_verification_for_all_source_uris disable_tls_peer_verification_for_all_destination_uris enable_tls_peer_verification_for_all_source_uris enable_tls_peer_verification_for_all_destination_uris help" -f -a "enable_tls_peer_verification_for_all_destination_uris" -d 'Enables TLS peer verification for all shovel destination URIs with provided [RabbitMQ node-local] certificate paths.'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and not __fish_seen_subcommand_from list_all list declare_amqp091 declare_amqp10 delete disable_tls_peer_verification_for_all_source_uris disable_tls_peer_verification_for_all_destination_uris enable_tls_peer_verification_for_all_source_uris enable_tls_peer_verification_for_all_destination_uris help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from list_all" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from list_all" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from list_all" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from list_all" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from list" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from list" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from list" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from list" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from declare_amqp091" -s n -l name -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from declare_amqp091" -l source-uri -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from declare_amqp091" -l destination-uri -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from declare_amqp091" -l ack-mode -d 'One of: on-confirm, on-publish, no-ack' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from declare_amqp091" -l source-queue -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from declare_amqp091" -l source-exchange -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from declare_amqp091" -l source-exchange-routing-key -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from declare_amqp091" -l destination-queue -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from declare_amqp091" -l destination-exchange -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from declare_amqp091" -l destination-exchange-routing-key -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from declare_amqp091" -l reconnect-delay -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from declare_amqp091" -l publish-properties -d 'A JSON object with message properties for the Shovel to set' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from declare_amqp091" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from declare_amqp091" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from declare_amqp091" -l predeclared-source -d 'The source topology will be pre-declared (should not be declared by the shovel)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from declare_amqp091" -l predeclared-destination -d 'The destination topology will be pre-declared (should not be declared by the shovel)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from declare_amqp091" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from declare_amqp091" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from declare_amqp10" -s n -l name -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from declare_amqp10" -l source-uri -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from declare_amqp10" -l destination-uri -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from declare_amqp10" -l ack-mode -d 'One of: on-confirm, on-publish, no-ack' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from declare_amqp10" -l source-address -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from declare_amqp10" -l destination-address -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from declare_amqp10" -l reconnect-delay -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from declare_amqp10" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from declare_amqp10" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from declare_amqp10" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from declare_amqp10" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from delete" -l name -d 'shovel name (identifier)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from delete" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from delete" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from delete" -l idempotently -d 'do not consider 404 Not Found API responses to be errors'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from delete" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from delete" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from disable_tls_peer_verification_for_all_source_uris" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from disable_tls_peer_verification_for_all_source_uris" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from disable_tls_peer_verification_for_all_source_uris" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from disable_tls_peer_verification_for_all_source_uris" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from disable_tls_peer_verification_for_all_destination_uris" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from disable_tls_peer_verification_for_all_destination_uris" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from disable_tls_peer_verification_for_all_destination_uris" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from disable_tls_peer_verification_for_all_destination_uris" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from enable_tls_peer_verification_for_all_source_uris" -l node-local-ca-certificate-bundle-path -d 'Path to the CA certificate bundle file on the target RabbitMQ node(s)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from enable_tls_peer_verification_for_all_source_uris" -l node-local-client-certificate-file-path -d 'Path to the client certificate file on the target RabbitMQ node(s)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from enable_tls_peer_verification_for_all_source_uris" -l node-local-client-private-key-file-path -d 'Path to the client private key file on the target RabbitMQ node(s)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from enable_tls_peer_verification_for_all_source_uris" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from enable_tls_peer_verification_for_all_source_uris" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from enable_tls_peer_verification_for_all_source_uris" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from enable_tls_peer_verification_for_all_source_uris" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from enable_tls_peer_verification_for_all_destination_uris" -l node-local-ca-certificate-bundle-path -d 'Path to the CA certificate bundle file on the target RabbitMQ node(s)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from enable_tls_peer_verification_for_all_destination_uris" -l node-local-client-certificate-file-path -d 'Path to the client certificate file on the target RabbitMQ node(s)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from enable_tls_peer_verification_for_all_destination_uris" -l node-local-client-private-key-file-path -d 'Path to the client private key file on the target RabbitMQ node(s)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from enable_tls_peer_verification_for_all_destination_uris" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from enable_tls_peer_verification_for_all_destination_uris" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from enable_tls_peer_verification_for_all_destination_uris" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from enable_tls_peer_verification_for_all_destination_uris" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from help" -f -a "list_all"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from help" -f -a "list"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from help" -f -a "declare_amqp091"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from help" -f -a "declare_amqp10"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from help" -f -a "delete"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from help" -f -a "disable_tls_peer_verification_for_all_source_uris" -d 'Use only in case of emergency. Disables TLS peer verification for all shovels.'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from help" -f -a "disable_tls_peer_verification_for_all_destination_uris" -d 'Use only in case of emergency. Disables TLS peer verification for all shovel destination URIs.'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from help" -f -a "enable_tls_peer_verification_for_all_source_uris" -d 'Enables TLS peer verification for all shovel source URIs with provided [RabbitMQ node-local] certificate paths.'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from help" -f -a "enable_tls_peer_verification_for_all_destination_uris" -d 'Enables TLS peer verification for all shovel destination URIs with provided [RabbitMQ node-local] certificate paths.'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand shovels; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand streams; and not __fish_seen_subcommand_from declare delete list show help" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand streams; and not __fish_seen_subcommand_from declare delete list show help" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand streams; and not __fish_seen_subcommand_from declare delete list show help" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand streams; and not __fish_seen_subcommand_from declare delete list show help" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand streams; and not __fish_seen_subcommand_from declare delete list show help" -f -a "declare" -d 'Declares a stream'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand streams; and not __fish_seen_subcommand_from declare delete list show help" -f -a "delete" -d 'Deletes a stream'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand streams; and not __fish_seen_subcommand_from declare delete list show help" -f -a "list"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand streams; and not __fish_seen_subcommand_from declare delete list show help" -f -a "show" -d 'Shows details for a single stream'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand streams; and not __fish_seen_subcommand_from declare delete list show help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand streams; and __fish_seen_subcommand_from declare" -l name -d 'name' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand streams; and __fish_seen_subcommand_from declare" -l expiration -d 'stream expiration, e.g. 12h for 12 hours, 7D for 7 days, or 1M for 1 month' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand streams; and __fish_seen_subcommand_from declare" -l max-length-bytes -d 'maximum stream length in bytes' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand streams; and __fish_seen_subcommand_from declare" -l stream-max-segment-size-bytes -d 'maximum stream segment file length in bytes' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand streams; and __fish_seen_subcommand_from declare" -l arguments -d 'additional stream arguments' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand streams; and __fish_seen_subcommand_from declare" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand streams; and __fish_seen_subcommand_from declare" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand streams; and __fish_seen_subcommand_from declare" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand streams; and __fish_seen_subcommand_from declare" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand streams; and __fish_seen_subcommand_from delete" -l name -d 'stream name' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand streams; and __fish_seen_subcommand_from delete" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand streams; and __fish_seen_subcommand_from delete" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand streams; and __fish_seen_subcommand_from delete" -l idempotently -d 'do not consider 404 Not Found API responses to be errors'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand streams; and __fish_seen_subcommand_from delete" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand streams; and __fish_seen_subcommand_from delete" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand streams; and __fish_seen_subcommand_from list" -l page -d 'page number (1-indexed)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand streams; and __fish_seen_subcommand_from list" -l page-size -d 'number of results per page (default: 100, max: 500)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand streams; and __fish_seen_subcommand_from list" -l columns -d 'comma-separated list of columns to display' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand streams; and __fish_seen_subcommand_from list" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand streams; and __fish_seen_subcommand_from list" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand streams; and __fish_seen_subcommand_from list" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand streams; and __fish_seen_subcommand_from list" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand streams; and __fish_seen_subcommand_from show" -l name -d 'stream name' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand streams; and __fish_seen_subcommand_from show" -l columns -d 'comma-separated list of columns to display' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand streams; and __fish_seen_subcommand_from show" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand streams; and __fish_seen_subcommand_from show" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand streams; and __fish_seen_subcommand_from show" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand streams; and __fish_seen_subcommand_from show" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand streams; and __fish_seen_subcommand_from help" -f -a "declare" -d 'Declares a stream'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand streams; and __fish_seen_subcommand_from help" -f -a "delete" -d 'Deletes a stream'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand streams; and __fish_seen_subcommand_from help" -f -a "list"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand streams; and __fish_seen_subcommand_from help" -f -a "show" -d 'Shows details for a single stream'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand streams; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand tanzu; and not __fish_seen_subcommand_from sds wsr help" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand tanzu; and not __fish_seen_subcommand_from sds wsr help" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand tanzu; and not __fish_seen_subcommand_from sds wsr help" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand tanzu; and not __fish_seen_subcommand_from sds wsr help" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand tanzu; and not __fish_seen_subcommand_from sds wsr help" -f -a "sds"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand tanzu; and not __fish_seen_subcommand_from sds wsr help" -f -a "wsr"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand tanzu; and not __fish_seen_subcommand_from sds wsr help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand tanzu; and __fish_seen_subcommand_from sds" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand tanzu; and __fish_seen_subcommand_from sds" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand tanzu; and __fish_seen_subcommand_from sds" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand tanzu; and __fish_seen_subcommand_from sds" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand tanzu; and __fish_seen_subcommand_from sds" -f -a "status_on_node"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand tanzu; and __fish_seen_subcommand_from sds" -f -a "disable_on_node"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand tanzu; and __fish_seen_subcommand_from sds" -f -a "disable_cluster_wide"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand tanzu; and __fish_seen_subcommand_from sds" -f -a "enable_on_node"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand tanzu; and __fish_seen_subcommand_from sds" -f -a "enable_cluster_wide"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand tanzu; and __fish_seen_subcommand_from sds" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand tanzu; and __fish_seen_subcommand_from wsr" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand tanzu; and __fish_seen_subcommand_from wsr" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand tanzu; and __fish_seen_subcommand_from wsr" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand tanzu; and __fish_seen_subcommand_from wsr" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand tanzu; and __fish_seen_subcommand_from wsr" -f -a "status"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand tanzu; and __fish_seen_subcommand_from wsr" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand tanzu; and __fish_seen_subcommand_from help" -f -a "sds"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand tanzu; and __fish_seen_subcommand_from help" -f -a "wsr"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand tanzu; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand users; and not __fish_seen_subcommand_from connections declare delete limits list permissions help" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand users; and not __fish_seen_subcommand_from connections declare delete limits list permissions help" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand users; and not __fish_seen_subcommand_from connections declare delete limits list permissions help" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand users; and not __fish_seen_subcommand_from connections declare delete limits list permissions help" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand users; and not __fish_seen_subcommand_from connections declare delete limits list permissions help" -f -a "connections"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand users; and not __fish_seen_subcommand_from connections declare delete limits list permissions help" -f -a "declare" -d 'Creates a user'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand users; and not __fish_seen_subcommand_from connections declare delete limits list permissions help" -f -a "delete" -d 'Deletes a user'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand users; and not __fish_seen_subcommand_from connections declare delete limits list permissions help" -f -a "limits"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand users; and not __fish_seen_subcommand_from connections declare delete limits list permissions help" -f -a "list"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand users; and not __fish_seen_subcommand_from connections declare delete limits list permissions help" -f -a "permissions"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand users; and not __fish_seen_subcommand_from connections declare delete limits list permissions help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand users; and __fish_seen_subcommand_from connections" -s u -l username -d 'Name of the user whose connections should be listed' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand users; and __fish_seen_subcommand_from connections" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand users; and __fish_seen_subcommand_from connections" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand users; and __fish_seen_subcommand_from connections" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand users; and __fish_seen_subcommand_from connections" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand users; and __fish_seen_subcommand_from declare" -l name -d 'username' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand users; and __fish_seen_subcommand_from declare" -l password-hash -d 'salted password hash, see https://rabbitmq.com/docs/passwords' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand users; and __fish_seen_subcommand_from declare" -l password -d 'prefer providing a hash, see https://rabbitmq.com/docs/passwords' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand users; and __fish_seen_subcommand_from declare" -l hashing-algorithm -d 'The hashing algorithm to use: SHA256 or SHA512' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand users; and __fish_seen_subcommand_from declare" -l tags -d 'a list of comma-separated tags' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand users; and __fish_seen_subcommand_from declare" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand users; and __fish_seen_subcommand_from declare" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand users; and __fish_seen_subcommand_from declare" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand users; and __fish_seen_subcommand_from declare" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand users; and __fish_seen_subcommand_from delete" -l name -d 'username' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand users; and __fish_seen_subcommand_from delete" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand users; and __fish_seen_subcommand_from delete" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand users; and __fish_seen_subcommand_from delete" -l idempotently -d 'do not consider 404 Not Found API responses to be errors'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand users; and __fish_seen_subcommand_from delete" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand users; and __fish_seen_subcommand_from delete" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand users; and __fish_seen_subcommand_from limits" -l username -d 'username' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand users; and __fish_seen_subcommand_from limits" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand users; and __fish_seen_subcommand_from limits" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand users; and __fish_seen_subcommand_from limits" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand users; and __fish_seen_subcommand_from limits" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand users; and __fish_seen_subcommand_from list" -l page -d 'page number (1-indexed)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand users; and __fish_seen_subcommand_from list" -l page-size -d 'number of results per page (default: 100, max: 500)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand users; and __fish_seen_subcommand_from list" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand users; and __fish_seen_subcommand_from list" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand users; and __fish_seen_subcommand_from list" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand users; and __fish_seen_subcommand_from list" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand users; and __fish_seen_subcommand_from permissions" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand users; and __fish_seen_subcommand_from permissions" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand users; and __fish_seen_subcommand_from permissions" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand users; and __fish_seen_subcommand_from permissions" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand users; and __fish_seen_subcommand_from help" -f -a "connections"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand users; and __fish_seen_subcommand_from help" -f -a "declare" -d 'Creates a user'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand users; and __fish_seen_subcommand_from help" -f -a "delete" -d 'Deletes a user'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand users; and __fish_seen_subcommand_from help" -f -a "limits"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand users; and __fish_seen_subcommand_from help" -f -a "list"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand users; and __fish_seen_subcommand_from help" -f -a "permissions"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand users; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand user_limits; and not __fish_seen_subcommand_from list declare delete help" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand user_limits; and not __fish_seen_subcommand_from list declare delete help" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand user_limits; and not __fish_seen_subcommand_from list declare delete help" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand user_limits; and not __fish_seen_subcommand_from list declare delete help" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand user_limits; and not __fish_seen_subcommand_from list declare delete help" -f -a "list"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand user_limits; and not __fish_seen_subcommand_from list declare delete help" -f -a "declare" -d 'Set a user limit'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand user_limits; and not __fish_seen_subcommand_from list declare delete help" -f -a "delete" -d 'Clears a user limit'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand user_limits; and not __fish_seen_subcommand_from list declare delete help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand user_limits; and __fish_seen_subcommand_from list" -l username -d 'username' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand user_limits; and __fish_seen_subcommand_from list" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand user_limits; and __fish_seen_subcommand_from list" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand user_limits; and __fish_seen_subcommand_from list" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand user_limits; and __fish_seen_subcommand_from list" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand user_limits; and __fish_seen_subcommand_from declare" -l username -d 'username' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand user_limits; and __fish_seen_subcommand_from declare" -l name -d 'limit name (eg. max-connections, max-queues)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand user_limits; and __fish_seen_subcommand_from declare" -l value -d 'limit value' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand user_limits; and __fish_seen_subcommand_from declare" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand user_limits; and __fish_seen_subcommand_from declare" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand user_limits; and __fish_seen_subcommand_from declare" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand user_limits; and __fish_seen_subcommand_from declare" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand user_limits; and __fish_seen_subcommand_from delete" -l username -d 'username' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand user_limits; and __fish_seen_subcommand_from delete" -l name -d 'limit name (eg. max-connections, max-queues)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand user_limits; and __fish_seen_subcommand_from delete" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand user_limits; and __fish_seen_subcommand_from delete" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand user_limits; and __fish_seen_subcommand_from delete" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand user_limits; and __fish_seen_subcommand_from delete" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand user_limits; and __fish_seen_subcommand_from help" -f -a "list"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand user_limits; and __fish_seen_subcommand_from help" -f -a "declare" -d 'Set a user limit'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand user_limits; and __fish_seen_subcommand_from help" -f -a "delete" -d 'Clears a user limit'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand user_limits; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhosts; and not __fish_seen_subcommand_from list declare delete delete_multiple enable_deletion_protection disable_deletion_protection help" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhosts; and not __fish_seen_subcommand_from list declare delete delete_multiple enable_deletion_protection disable_deletion_protection help" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhosts; and not __fish_seen_subcommand_from list declare delete delete_multiple enable_deletion_protection disable_deletion_protection help" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhosts; and not __fish_seen_subcommand_from list declare delete delete_multiple enable_deletion_protection disable_deletion_protection help" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhosts; and not __fish_seen_subcommand_from list declare delete delete_multiple enable_deletion_protection disable_deletion_protection help" -f -a "list"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhosts; and not __fish_seen_subcommand_from list declare delete delete_multiple enable_deletion_protection disable_deletion_protection help" -f -a "declare" -d 'Creates a virtual host'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhosts; and not __fish_seen_subcommand_from list declare delete delete_multiple enable_deletion_protection disable_deletion_protection help" -f -a "delete" -d 'Deletes a virtual host'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhosts; and not __fish_seen_subcommand_from list declare delete delete_multiple enable_deletion_protection disable_deletion_protection help" -f -a "delete_multiple" -d 'DANGER ZONE. Deletes multiple virtual hosts at once using a name matching pattern'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhosts; and not __fish_seen_subcommand_from list declare delete delete_multiple enable_deletion_protection disable_deletion_protection help" -f -a "enable_deletion_protection" -d 'Enables deletion protection for a virtual host'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhosts; and not __fish_seen_subcommand_from list declare delete delete_multiple enable_deletion_protection disable_deletion_protection help" -f -a "disable_deletion_protection" -d 'Disables deletion protection for a virtual host'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhosts; and not __fish_seen_subcommand_from list declare delete delete_multiple enable_deletion_protection disable_deletion_protection help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhosts; and __fish_seen_subcommand_from list" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhosts; and __fish_seen_subcommand_from list" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhosts; and __fish_seen_subcommand_from list" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhosts; and __fish_seen_subcommand_from list" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhosts; and __fish_seen_subcommand_from declare" -l name -d 'virtual host name' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhosts; and __fish_seen_subcommand_from declare" -l default-queue-type -d 'default queue type, one of: classic, quorum, stream' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhosts; and __fish_seen_subcommand_from declare" -l description -d 'what\'s the purpose of this virtual host?' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhosts; and __fish_seen_subcommand_from declare" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhosts; and __fish_seen_subcommand_from declare" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhosts; and __fish_seen_subcommand_from declare" -l tracing -d 'should tracing be enabled for this virtual host?'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhosts; and __fish_seen_subcommand_from declare" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhosts; and __fish_seen_subcommand_from declare" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhosts; and __fish_seen_subcommand_from delete" -l name -d 'virtual host' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhosts; and __fish_seen_subcommand_from delete" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhosts; and __fish_seen_subcommand_from delete" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhosts; and __fish_seen_subcommand_from delete" -l idempotently -d 'do not consider 404 Not Found API responses to be errors'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhosts; and __fish_seen_subcommand_from delete" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhosts; and __fish_seen_subcommand_from delete" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhosts; and __fish_seen_subcommand_from delete_multiple" -l name-pattern -d 'a regular expression that will be used to match virtual host names' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhosts; and __fish_seen_subcommand_from delete_multiple" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhosts; and __fish_seen_subcommand_from delete_multiple" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhosts; and __fish_seen_subcommand_from delete_multiple" -l approve -d 'this operation is very destructive and requires an explicit approval'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhosts; and __fish_seen_subcommand_from delete_multiple" -l dry-run -d 'show what would be deleted without performing the actual deletion'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhosts; and __fish_seen_subcommand_from delete_multiple" -l idempotently -d 'do not consider 404 Not Found API responses to be errors'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhosts; and __fish_seen_subcommand_from delete_multiple" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhosts; and __fish_seen_subcommand_from delete_multiple" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhosts; and __fish_seen_subcommand_from enable_deletion_protection" -l name -d 'virtual host name' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhosts; and __fish_seen_subcommand_from enable_deletion_protection" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhosts; and __fish_seen_subcommand_from enable_deletion_protection" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhosts; and __fish_seen_subcommand_from enable_deletion_protection" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhosts; and __fish_seen_subcommand_from enable_deletion_protection" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhosts; and __fish_seen_subcommand_from disable_deletion_protection" -l name -d 'virtual host name' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhosts; and __fish_seen_subcommand_from disable_deletion_protection" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhosts; and __fish_seen_subcommand_from disable_deletion_protection" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhosts; and __fish_seen_subcommand_from disable_deletion_protection" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhosts; and __fish_seen_subcommand_from disable_deletion_protection" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhosts; and __fish_seen_subcommand_from help" -f -a "list"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhosts; and __fish_seen_subcommand_from help" -f -a "declare" -d 'Creates a virtual host'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhosts; and __fish_seen_subcommand_from help" -f -a "delete" -d 'Deletes a virtual host'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhosts; and __fish_seen_subcommand_from help" -f -a "delete_multiple" -d 'DANGER ZONE. Deletes multiple virtual hosts at once using a name matching pattern'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhosts; and __fish_seen_subcommand_from help" -f -a "enable_deletion_protection" -d 'Enables deletion protection for a virtual host'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhosts; and __fish_seen_subcommand_from help" -f -a "disable_deletion_protection" -d 'Disables deletion protection for a virtual host'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhosts; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhost_limits; and not __fish_seen_subcommand_from list declare delete help" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhost_limits; and not __fish_seen_subcommand_from list declare delete help" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhost_limits; and not __fish_seen_subcommand_from list declare delete help" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhost_limits; and not __fish_seen_subcommand_from list declare delete help" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhost_limits; and not __fish_seen_subcommand_from list declare delete help" -f -a "list"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhost_limits; and not __fish_seen_subcommand_from list declare delete help" -f -a "declare" -d 'Set a vhost limit'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhost_limits; and not __fish_seen_subcommand_from list declare delete help" -f -a "delete" -d 'delete a vhost limit'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhost_limits; and not __fish_seen_subcommand_from list declare delete help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhost_limits; and __fish_seen_subcommand_from list" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhost_limits; and __fish_seen_subcommand_from list" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhost_limits; and __fish_seen_subcommand_from list" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhost_limits; and __fish_seen_subcommand_from list" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhost_limits; and __fish_seen_subcommand_from declare" -l name -d 'limit name (eg. max-connections, max-queues)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhost_limits; and __fish_seen_subcommand_from declare" -l value -d 'limit value' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhost_limits; and __fish_seen_subcommand_from declare" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhost_limits; and __fish_seen_subcommand_from declare" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhost_limits; and __fish_seen_subcommand_from declare" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhost_limits; and __fish_seen_subcommand_from declare" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhost_limits; and __fish_seen_subcommand_from delete" -l name -d 'limit name (eg. max-connections, max-queues)' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhost_limits; and __fish_seen_subcommand_from delete" -s V -l vhost -d 'target virtual host. Defaults to \'/\'' -r
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhost_limits; and __fish_seen_subcommand_from delete" -l table-style -d 'style preset to apply to output tables: modern, borderless, ascii, dots, psql, markdown, sharp' -r -f -a "modern\t''
borderless\t''
markdown\t''
sharp\t''
ascii\t''
psql\t''
dots\t''"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhost_limits; and __fish_seen_subcommand_from delete" -l non-interactive -d 'pass when invoking from scripts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhost_limits; and __fish_seen_subcommand_from delete" -s h -l help -d 'Print help'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhost_limits; and __fish_seen_subcommand_from help" -f -a "list"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhost_limits; and __fish_seen_subcommand_from help" -f -a "declare" -d 'Set a vhost limit'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhost_limits; and __fish_seen_subcommand_from help" -f -a "delete" -d 'delete a vhost limit'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand vhost_limits; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and not __fish_seen_subcommand_from auth_attempts bindings channels close config_file connections declare definitions delete deprecated_features exchanges export feature_flags federation get global_parameters health_check import list nodes operator_policies parameters passwords permissions plugins policies publish purge queues rebalance shell show shovels streams tanzu users user_limits vhosts vhost_limits help" -f -a "auth_attempts" -d 'Authentication attempt statistics'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and not __fish_seen_subcommand_from auth_attempts bindings channels close config_file connections declare definitions delete deprecated_features exchanges export feature_flags federation get global_parameters health_check import list nodes operator_policies parameters passwords permissions plugins policies publish purge queues rebalance shell show shovels streams tanzu users user_limits vhosts vhost_limits help" -f -a "bindings" -d 'Operations on bindings'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and not __fish_seen_subcommand_from auth_attempts bindings channels close config_file connections declare definitions delete deprecated_features exchanges export feature_flags federation get global_parameters health_check import list nodes operator_policies parameters passwords permissions plugins policies publish purge queues rebalance shell show shovels streams tanzu users user_limits vhosts vhost_limits help" -f -a "channels" -d 'Operations on channels'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and not __fish_seen_subcommand_from auth_attempts bindings channels close config_file connections declare definitions delete deprecated_features exchanges export feature_flags federation get global_parameters health_check import list nodes operator_policies parameters passwords permissions plugins policies publish purge queues rebalance shell show shovels streams tanzu users user_limits vhosts vhost_limits help" -f -a "close" -d 'Closes connections'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and not __fish_seen_subcommand_from auth_attempts bindings channels close config_file connections declare definitions delete deprecated_features exchanges export feature_flags federation get global_parameters health_check import list nodes operator_policies parameters passwords permissions plugins policies publish purge queues rebalance shell show shovels streams tanzu users user_limits vhosts vhost_limits help" -f -a "config_file" -d 'Operations on the local configuration file'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and not __fish_seen_subcommand_from auth_attempts bindings channels close config_file connections declare definitions delete deprecated_features exchanges export feature_flags federation get global_parameters health_check import list nodes operator_policies parameters passwords permissions plugins policies publish purge queues rebalance shell show shovels streams tanzu users user_limits vhosts vhost_limits help" -f -a "connections" -d 'Operations on connections'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and not __fish_seen_subcommand_from auth_attempts bindings channels close config_file connections declare definitions delete deprecated_features exchanges export feature_flags federation get global_parameters health_check import list nodes operator_policies parameters passwords permissions plugins policies publish purge queues rebalance shell show shovels streams tanzu users user_limits vhosts vhost_limits help" -f -a "declare" -d 'Creates or declares objects'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and not __fish_seen_subcommand_from auth_attempts bindings channels close config_file connections declare definitions delete deprecated_features exchanges export feature_flags federation get global_parameters health_check import list nodes operator_policies parameters passwords permissions plugins policies publish purge queues rebalance shell show shovels streams tanzu users user_limits vhosts vhost_limits help" -f -a "definitions" -d 'Operations on definitions (everything except for messages: virtual hosts, queues, streams, exchanges, bindings, users, etc)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and not __fish_seen_subcommand_from auth_attempts bindings channels close config_file connections declare definitions delete deprecated_features exchanges export feature_flags federation get global_parameters health_check import list nodes operator_policies parameters passwords permissions plugins policies publish purge queues rebalance shell show shovels streams tanzu users user_limits vhosts vhost_limits help" -f -a "delete" -d 'Deletes objects'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and not __fish_seen_subcommand_from auth_attempts bindings channels close config_file connections declare definitions delete deprecated_features exchanges export feature_flags federation get global_parameters health_check import list nodes operator_policies parameters passwords permissions plugins policies publish purge queues rebalance shell show shovels streams tanzu users user_limits vhosts vhost_limits help" -f -a "deprecated_features" -d 'Operations on deprecated features'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and not __fish_seen_subcommand_from auth_attempts bindings channels close config_file connections declare definitions delete deprecated_features exchanges export feature_flags federation get global_parameters health_check import list nodes operator_policies parameters passwords permissions plugins policies publish purge queues rebalance shell show shovels streams tanzu users user_limits vhosts vhost_limits help" -f -a "exchanges" -d 'Operations on exchanges'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and not __fish_seen_subcommand_from auth_attempts bindings channels close config_file connections declare definitions delete deprecated_features exchanges export feature_flags federation get global_parameters health_check import list nodes operator_policies parameters passwords permissions plugins policies publish purge queues rebalance shell show shovels streams tanzu users user_limits vhosts vhost_limits help" -f -a "export" -d 'See \'definitions export\''
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and not __fish_seen_subcommand_from auth_attempts bindings channels close config_file connections declare definitions delete deprecated_features exchanges export feature_flags federation get global_parameters health_check import list nodes operator_policies parameters passwords permissions plugins policies publish purge queues rebalance shell show shovels streams tanzu users user_limits vhosts vhost_limits help" -f -a "feature_flags" -d 'Operations on feature flags'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and not __fish_seen_subcommand_from auth_attempts bindings channels close config_file connections declare definitions delete deprecated_features exchanges export feature_flags federation get global_parameters health_check import list nodes operator_policies parameters passwords permissions plugins policies publish purge queues rebalance shell show shovels streams tanzu users user_limits vhosts vhost_limits help" -f -a "federation" -d 'Operations on federation upstreams and links'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and not __fish_seen_subcommand_from auth_attempts bindings channels close config_file connections declare definitions delete deprecated_features exchanges export feature_flags federation get global_parameters health_check import list nodes operator_policies parameters passwords permissions plugins policies publish purge queues rebalance shell show shovels streams tanzu users user_limits vhosts vhost_limits help" -f -a "get" -d 'Fetches message(s) from a queue or stream via polling. Only suitable for development and test environments.'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and not __fish_seen_subcommand_from auth_attempts bindings channels close config_file connections declare definitions delete deprecated_features exchanges export feature_flags federation get global_parameters health_check import list nodes operator_policies parameters passwords permissions plugins policies publish purge queues rebalance shell show shovels streams tanzu users user_limits vhosts vhost_limits help" -f -a "global_parameters" -d 'Operations on global runtime parameters'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and not __fish_seen_subcommand_from auth_attempts bindings channels close config_file connections declare definitions delete deprecated_features exchanges export feature_flags federation get global_parameters health_check import list nodes operator_policies parameters passwords permissions plugins policies publish purge queues rebalance shell show shovels streams tanzu users user_limits vhosts vhost_limits help" -f -a "health_check" -d 'Runs health checks'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and not __fish_seen_subcommand_from auth_attempts bindings channels close config_file connections declare definitions delete deprecated_features exchanges export feature_flags federation get global_parameters health_check import list nodes operator_policies parameters passwords permissions plugins policies publish purge queues rebalance shell show shovels streams tanzu users user_limits vhosts vhost_limits help" -f -a "import" -d 'See \'definitions import\''
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and not __fish_seen_subcommand_from auth_attempts bindings channels close config_file connections declare definitions delete deprecated_features exchanges export feature_flags federation get global_parameters health_check import list nodes operator_policies parameters passwords permissions plugins policies publish purge queues rebalance shell show shovels streams tanzu users user_limits vhosts vhost_limits help" -f -a "list" -d 'Lists objects'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and not __fish_seen_subcommand_from auth_attempts bindings channels close config_file connections declare definitions delete deprecated_features exchanges export feature_flags federation get global_parameters health_check import list nodes operator_policies parameters passwords permissions plugins policies publish purge queues rebalance shell show shovels streams tanzu users user_limits vhosts vhost_limits help" -f -a "nodes" -d 'Node operations'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and not __fish_seen_subcommand_from auth_attempts bindings channels close config_file connections declare definitions delete deprecated_features exchanges export feature_flags federation get global_parameters health_check import list nodes operator_policies parameters passwords permissions plugins policies publish purge queues rebalance shell show shovels streams tanzu users user_limits vhosts vhost_limits help" -f -a "operator_policies" -d 'Operations on operator policies'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and not __fish_seen_subcommand_from auth_attempts bindings channels close config_file connections declare definitions delete deprecated_features exchanges export feature_flags federation get global_parameters health_check import list nodes operator_policies parameters passwords permissions plugins policies publish purge queues rebalance shell show shovels streams tanzu users user_limits vhosts vhost_limits help" -f -a "parameters" -d 'Operations on runtime parameters'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and not __fish_seen_subcommand_from auth_attempts bindings channels close config_file connections declare definitions delete deprecated_features exchanges export feature_flags federation get global_parameters health_check import list nodes operator_policies parameters passwords permissions plugins policies publish purge queues rebalance shell show shovels streams tanzu users user_limits vhosts vhost_limits help" -f -a "passwords" -d 'Operations on passwords'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and not __fish_seen_subcommand_from auth_attempts bindings channels close config_file connections declare definitions delete deprecated_features exchanges export feature_flags federation get global_parameters health_check import list nodes operator_policies parameters passwords permissions plugins policies publish purge queues rebalance shell show shovels streams tanzu users user_limits vhosts vhost_limits help" -f -a "permissions" -d 'Operations on user permissions'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and not __fish_seen_subcommand_from auth_attempts bindings channels close config_file connections declare definitions delete deprecated_features exchanges export feature_flags federation get global_parameters health_check import list nodes operator_policies parameters passwords permissions plugins policies publish purge queues rebalance shell show shovels streams tanzu users user_limits vhosts vhost_limits help" -f -a "plugins" -d 'List enabled plugins'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and not __fish_seen_subcommand_from auth_attempts bindings channels close config_file connections declare definitions delete deprecated_features exchanges export feature_flags federation get global_parameters health_check import list nodes operator_policies parameters passwords permissions plugins policies publish purge queues rebalance shell show shovels streams tanzu users user_limits vhosts vhost_limits help" -f -a "policies" -d 'Operations on policies'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and not __fish_seen_subcommand_from auth_attempts bindings channels close config_file connections declare definitions delete deprecated_features exchanges export feature_flags federation get global_parameters health_check import list nodes operator_policies parameters passwords permissions plugins policies publish purge queues rebalance shell show shovels streams tanzu users user_limits vhosts vhost_limits help" -f -a "publish" -d 'Publishes (inefficiently) message(s) to a queue or a stream. Only suitable for development and test environments.'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and not __fish_seen_subcommand_from auth_attempts bindings channels close config_file connections declare definitions delete deprecated_features exchanges export feature_flags federation get global_parameters health_check import list nodes operator_policies parameters passwords permissions plugins policies publish purge queues rebalance shell show shovels streams tanzu users user_limits vhosts vhost_limits help" -f -a "purge" -d 'Purges queues'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and not __fish_seen_subcommand_from auth_attempts bindings channels close config_file connections declare definitions delete deprecated_features exchanges export feature_flags federation get global_parameters health_check import list nodes operator_policies parameters passwords permissions plugins policies publish purge queues rebalance shell show shovels streams tanzu users user_limits vhosts vhost_limits help" -f -a "queues" -d 'Operations on queues'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and not __fish_seen_subcommand_from auth_attempts bindings channels close config_file connections declare definitions delete deprecated_features exchanges export feature_flags federation get global_parameters health_check import list nodes operator_policies parameters passwords permissions plugins policies publish purge queues rebalance shell show shovels streams tanzu users user_limits vhosts vhost_limits help" -f -a "rebalance" -d 'Rebalancing of leader replicas'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and not __fish_seen_subcommand_from auth_attempts bindings channels close config_file connections declare definitions delete deprecated_features exchanges export feature_flags federation get global_parameters health_check import list nodes operator_policies parameters passwords permissions plugins policies publish purge queues rebalance shell show shovels streams tanzu users user_limits vhosts vhost_limits help" -f -a "shell" -d 'Shell-related operations'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and not __fish_seen_subcommand_from auth_attempts bindings channels close config_file connections declare definitions delete deprecated_features exchanges export feature_flags federation get global_parameters health_check import list nodes operator_policies parameters passwords permissions plugins policies publish purge queues rebalance shell show shovels streams tanzu users user_limits vhosts vhost_limits help" -f -a "show" -d 'Overview, memory footprint breakdown, and more'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and not __fish_seen_subcommand_from auth_attempts bindings channels close config_file connections declare definitions delete deprecated_features exchanges export feature_flags federation get global_parameters health_check import list nodes operator_policies parameters passwords permissions plugins policies publish purge queues rebalance shell show shovels streams tanzu users user_limits vhosts vhost_limits help" -f -a "shovels" -d 'Operations on shovels'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and not __fish_seen_subcommand_from auth_attempts bindings channels close config_file connections declare definitions delete deprecated_features exchanges export feature_flags federation get global_parameters health_check import list nodes operator_policies parameters passwords permissions plugins policies publish purge queues rebalance shell show shovels streams tanzu users user_limits vhosts vhost_limits help" -f -a "streams" -d 'Operations on streams'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and not __fish_seen_subcommand_from auth_attempts bindings channels close config_file connections declare definitions delete deprecated_features exchanges export feature_flags federation get global_parameters health_check import list nodes operator_policies parameters passwords permissions plugins policies publish purge queues rebalance shell show shovels streams tanzu users user_limits vhosts vhost_limits help" -f -a "tanzu" -d 'Tanzu RabbitMQ-specific commands'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and not __fish_seen_subcommand_from auth_attempts bindings channels close config_file connections declare definitions delete deprecated_features exchanges export feature_flags federation get global_parameters health_check import list nodes operator_policies parameters passwords permissions plugins policies publish purge queues rebalance shell show shovels streams tanzu users user_limits vhosts vhost_limits help" -f -a "users" -d 'Operations on users'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and not __fish_seen_subcommand_from auth_attempts bindings channels close config_file connections declare definitions delete deprecated_features exchanges export feature_flags federation get global_parameters health_check import list nodes operator_policies parameters passwords permissions plugins policies publish purge queues rebalance shell show shovels streams tanzu users user_limits vhosts vhost_limits help" -f -a "user_limits" -d 'Operations on per-user (resource) limits'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and not __fish_seen_subcommand_from auth_attempts bindings channels close config_file connections declare definitions delete deprecated_features exchanges export feature_flags federation get global_parameters health_check import list nodes operator_policies parameters passwords permissions plugins policies publish purge queues rebalance shell show shovels streams tanzu users user_limits vhosts vhost_limits help" -f -a "vhosts" -d 'Virtual host operations'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and not __fish_seen_subcommand_from auth_attempts bindings channels close config_file connections declare definitions delete deprecated_features exchanges export feature_flags federation get global_parameters health_check import list nodes operator_policies parameters passwords permissions plugins policies publish purge queues rebalance shell show shovels streams tanzu users user_limits vhosts vhost_limits help" -f -a "vhost_limits" -d 'Operations on virtual host (resource) limits'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and not __fish_seen_subcommand_from auth_attempts bindings channels close config_file connections declare definitions delete deprecated_features exchanges export feature_flags federation get global_parameters health_check import list nodes operator_policies parameters passwords permissions plugins policies publish purge queues rebalance shell show shovels streams tanzu users user_limits vhosts vhost_limits help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from auth_attempts" -f -a "stats" -d 'Displays authentication attempt statistics for a cluster node'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from bindings" -f -a "declare" -d 'Creates a binding between a source exchange and a destination (a queue or an exchange)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from bindings" -f -a "delete" -d 'Deletes a binding'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from bindings" -f -a "list"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from channels" -f -a "list"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from close" -f -a "connection" -d 'Closes a client connection'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from close" -f -a "user_connections" -d 'Closes all connections that authenticated with a specific username'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from config_file" -f -a "show_path" -d 'Shows the path to the local rabbitmqadmin configuration file'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from config_file" -f -a "show" -d 'Shows the contents of the local rabbitmqadmin configuration file'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from config_file" -f -a "add_node" -d 'Adds a new node entry to the local rabbitmqadmin configuration file'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from config_file" -f -a "update_node" -d 'Updates an existing node entry in the local rabbitmqadmin configuration file (or creates one if it does not exist)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from config_file" -f -a "delete_node" -d 'Deletes a node entry from the local rabbitmqadmin configuration file'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from connections" -f -a "close" -d 'Closes a client connection'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from connections" -f -a "close_of_user" -d 'Closes all connections that are authenticated with a specific username'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from connections" -f -a "list"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from connections" -f -a "list_of_user"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from declare" -f -a "user" -d 'Creates a user'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from declare" -f -a "vhost" -d 'Creates a virtual host'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from declare" -f -a "permissions" -d 'grants permissions to a user'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from declare" -f -a "queue" -d 'Declares a queue or a stream'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from declare" -f -a "stream" -d 'Declares a stream'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from declare" -f -a "exchange" -d 'Declares an exchange'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from declare" -f -a "binding" -d 'Creates a binding between a source exchange and a destination (a queue or an exchange)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from declare" -f -a "parameter" -d 'Sets a runtime parameter'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from declare" -f -a "policy" -d 'Creates or updates a policy'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from declare" -f -a "operator_policy" -d 'Creates or updates an operator policy'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from declare" -f -a "vhost_limit" -d 'Set a vhost limit'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from declare" -f -a "user_limit" -d 'Set a user limit'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from definitions" -f -a "export" -d 'Export cluster-wide definitions'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from definitions" -f -a "export_from_vhost" -d 'Export definitions of a specific virtual host'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from definitions" -f -a "import" -d 'Import cluster-wide definitions (of multiple virtual hosts)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from definitions" -f -a "import_into_vhost" -d 'Import a virtual host-specific definitions file into a virtual host'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from delete" -f -a "user" -d 'Deletes a user'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from delete" -f -a "vhost" -d 'Deletes a virtual host'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from delete" -f -a "permissions" -d 'Revokes user permissions to a given vhost'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from delete" -f -a "queue" -d 'Deletes a queue'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from delete" -f -a "stream" -d 'Deletes a stream'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from delete" -f -a "exchange" -d 'Deletes an exchange'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from delete" -f -a "binding" -d 'Deletes a binding'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from delete" -f -a "parameter" -d 'Clears a runtime parameter'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from delete" -f -a "policy" -d 'Deletes a policy'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from delete" -f -a "operator_policy" -d 'Deletes an operator policy'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from delete" -f -a "vhost_limit" -d 'delete a vhost limit'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from delete" -f -a "user_limit" -d 'Clears a user limit'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from delete" -f -a "shovel" -d 'Delete a shovel'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from deprecated_features" -f -a "list"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from deprecated_features" -f -a "list_used"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from exchanges" -f -a "bind" -d 'Creates a binding between a source exchange and a destination (a queue or an exchange)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from exchanges" -f -a "declare" -d 'Declares an exchange'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from exchanges" -f -a "delete" -d 'Deletes an exchange'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from exchanges" -f -a "list"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from exchanges" -f -a "unbind" -d 'Deletes a binding'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from export" -f -a "definitions" -d 'Export cluster-wide definitions'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from feature_flags" -f -a "list"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from feature_flags" -f -a "enable"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from feature_flags" -f -a "enable_all"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from federation" -f -a "list_all_upstreams"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from federation" -f -a "declare_upstream"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from federation" -f -a "declare_upstream_for_exchanges"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from federation" -f -a "declare_upstream_for_queues"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from federation" -f -a "delete_upstream"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from federation" -f -a "list_all_links"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from federation" -f -a "disable_tls_peer_verification_for_all_upstreams" -d 'Use only in case of emergency. Disables TLS peer verification for all federation upstreams.'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from federation" -f -a "enable_tls_peer_verification_for_all_upstreams" -d 'Enables TLS peer verification for all federation upstreams with provided [RabbitMQ node-local] certificate paths.'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from get" -f -a "messages" -d 'Fetches (via polling, very inefficiently) message(s) from a queue. Only suitable for development and test environments'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from global_parameters" -f -a "clear" -d 'Clears (deletes) a global runtime parameter'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from global_parameters" -f -a "list"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from global_parameters" -f -a "set" -d 'Sets a global runtime parameter'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from health_check" -f -a "local_alarms" -d 'Checks if there are any resource alarms in effect on the target node'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from health_check" -f -a "cluster_wide_alarms" -d 'Checks if there are any resource alarms in effect across the entire cluster'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from health_check" -f -a "node_is_quorum_critical" -d 'Fails if there are queues/streams with minimum online quorum (queues/streams that will lose their quorum if the target node shuts down)'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from health_check" -f -a "deprecated_features_in_use" -d 'Fails if there are any deprecated features in use in the cluster'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from health_check" -f -a "port_listener" -d 'Verifies that there\'s a reachable TCP listener on the given port on the target node'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from health_check" -f -a "protocol_listener" -d 'Verifies that there\'s a reachable TCP listener on the given protocol alias on the target node'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from import" -f -a "definitions" -d 'Prefer \'definitions import\''
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from list" -f -a "nodes"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from list" -f -a "users"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from list" -f -a "vhosts"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from list" -f -a "permissions"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from list" -f -a "connections"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from list" -f -a "user_connections"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from list" -f -a "channels"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from list" -f -a "queues"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from list" -f -a "exchanges"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from list" -f -a "bindings"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from list" -f -a "consumers"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from list" -f -a "parameters"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from list" -f -a "policies"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from list" -f -a "operator_policies"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from list" -f -a "vhost_limits"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from list" -f -a "user_limits"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from list" -f -a "feature_flags"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from list" -f -a "deprecated_features"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from list" -f -a "deprecated_features_in_use"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from nodes" -f -a "list"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from nodes" -f -a "memory_breakdown_in_percent" -d 'Provides a memory footprint breakdown (in percent) for the target node'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from nodes" -f -a "memory_breakdown_in_bytes" -d 'Provides a memory footprint breakdown (in bytes) for the target node'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from operator_policies" -f -a "declare" -d 'Creates or updates an operator policy'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from operator_policies" -f -a "delete" -d 'Deletes an operator policy'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from operator_policies" -f -a "delete_definition_keys" -d 'Deletes definition keys from an operator policy, unless it is the only key'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from operator_policies" -f -a "delete_definition_keys_from_all_in" -d 'Deletes a definition key from all operator policies in a virtual host, unless it is the only key'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from operator_policies" -f -a "list"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from operator_policies" -f -a "list_in" -d 'Lists operator policies in a specific virtual host'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from operator_policies" -f -a "list_matching_object" -d 'Lists operator policies that match an object (queue, stream, exchange) name'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from operator_policies" -f -a "patch" -d 'Merges a set of keys into existing operator policy definitions'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from operator_policies" -f -a "update_definition" -d 'Updates an operator policy definition key'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from operator_policies" -f -a "update_definitions_of_all_in" -d 'Updates a definition key in all operator policies in a virtual host'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from parameters" -f -a "clear" -d 'Clears (deletes) a runtime parameter'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from parameters" -f -a "list_all"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from parameters" -f -a "list"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from parameters" -f -a "list_in"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from parameters" -f -a "set" -d 'Sets a runtime parameter'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from passwords" -f -a "salt_and_hash"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from permissions" -f -a "list"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from permissions" -f -a "declare" -d 'grants permissions to a user'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from permissions" -f -a "delete" -d 'Revokes user permissions to a given vhost'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from plugins" -f -a "list_all" -d 'Lists plugins across all cluster nodes'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from plugins" -f -a "list_on_node" -d 'Lists plugins enabled on a specific node'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from policies" -f -a "declare" -d 'Creates or updates a policy'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from policies" -f -a "declare_override" -d 'Declares a new policy from an existing one, with a higher priority, and merges a set of keys into the new overriding policy definition'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from policies" -f -a "declare_blanket" -d 'Creates a low priority blanket policy, a policy that matches all objects not matched by any other policy'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from policies" -f -a "delete" -d 'Deletes a policy'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from policies" -f -a "delete_definition_keys" -d 'Deletes a definition key from a policy, unless it is the only key'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from policies" -f -a "delete_definition_keys_from_all" -d 'Deletes definition keys from all policies in the cluster, unless it is the only policy key'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from policies" -f -a "delete_definition_keys_from_all_in" -d 'Deletes definition keys from all policies in a virtual host, unless it is the only policy key'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from policies" -f -a "list"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from policies" -f -a "list_conflicting" -d 'Lists policies that have conflicting priorities across all virtual hosts'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from policies" -f -a "list_conflicting_in" -d 'Lists policies that have conflicting priorities in a specific virtual host'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from policies" -f -a "list_in" -d 'Lists policies in a specific virtual host'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from policies" -f -a "list_matching_object" -d 'Lists policies that match an object (queue, stream, exchange) name'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from policies" -f -a "patch" -d 'Merges a set of keys into existing policy definitions'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from policies" -f -a "update_definition" -d 'Updates a policy definition key'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from policies" -f -a "update_definitions_of_all" -d 'Updates a definition key in all policies in the cluster'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from policies" -f -a "update_definitions_of_all_in" -d 'Updates a definition key in all policies in a virtual host'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from publish" -f -a "message" -d 'Publishes (inefficiently) message(s) to a queue or a stream. Only suitable for development and test environments. Prefer messaging or streaming protocol clients!'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from purge" -f -a "queue"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from queues" -f -a "declare" -d 'Declares a queue or a stream'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from queues" -f -a "delete" -d 'Deletes a queue'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from queues" -f -a "list"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from queues" -f -a "purge"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from queues" -f -a "rebalance" -d 'Rebalances queue leaders'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from queues" -f -a "show" -d 'Shows details for a single queue'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from rebalance" -f -a "queues" -d 'Rebalances queue leaders'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from shell" -f -a "completions" -d 'Generate shell completion scripts for the CLI'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from show" -f -a "overview" -d 'Displays essential information about target node and its cluster'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from show" -f -a "churn" -d 'Displays object churn metrics'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from show" -f -a "endpoint" -d 'Displays the computed HTTP API endpoint URI. Use for troubleshooting only.'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from show" -f -a "memory_breakdown_in_bytes" -d 'Provides a memory footprint breakdown (in bytes) for the target node'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from show" -f -a "memory_breakdown_in_percent" -d 'Provides a memory footprint breakdown (in percent) for the target node'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from shovels" -f -a "list_all"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from shovels" -f -a "list"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from shovels" -f -a "declare_amqp091"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from shovels" -f -a "declare_amqp10"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from shovels" -f -a "delete"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from shovels" -f -a "disable_tls_peer_verification_for_all_source_uris" -d 'Use only in case of emergency. Disables TLS peer verification for all shovels.'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from shovels" -f -a "disable_tls_peer_verification_for_all_destination_uris" -d 'Use only in case of emergency. Disables TLS peer verification for all shovel destination URIs.'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from shovels" -f -a "enable_tls_peer_verification_for_all_source_uris" -d 'Enables TLS peer verification for all shovel source URIs with provided [RabbitMQ node-local] certificate paths.'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from shovels" -f -a "enable_tls_peer_verification_for_all_destination_uris" -d 'Enables TLS peer verification for all shovel destination URIs with provided [RabbitMQ node-local] certificate paths.'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from streams" -f -a "declare" -d 'Declares a stream'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from streams" -f -a "delete" -d 'Deletes a stream'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from streams" -f -a "list"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from streams" -f -a "show" -d 'Shows details for a single stream'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from tanzu" -f -a "sds"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from tanzu" -f -a "wsr"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from users" -f -a "connections"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from users" -f -a "declare" -d 'Creates a user'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from users" -f -a "delete" -d 'Deletes a user'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from users" -f -a "limits"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from users" -f -a "list"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from users" -f -a "permissions"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from user_limits" -f -a "list"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from user_limits" -f -a "declare" -d 'Set a user limit'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from user_limits" -f -a "delete" -d 'Clears a user limit'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from vhosts" -f -a "list"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from vhosts" -f -a "declare" -d 'Creates a virtual host'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from vhosts" -f -a "delete" -d 'Deletes a virtual host'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from vhosts" -f -a "delete_multiple" -d 'DANGER ZONE. Deletes multiple virtual hosts at once using a name matching pattern'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from vhosts" -f -a "enable_deletion_protection" -d 'Enables deletion protection for a virtual host'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from vhosts" -f -a "disable_deletion_protection" -d 'Disables deletion protection for a virtual host'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from vhost_limits" -f -a "list"
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from vhost_limits" -f -a "declare" -d 'Set a vhost limit'
complete -c rabbitmqadmin -n "__fish_rabbitmqadmin_using_subcommand help; and __fish_seen_subcommand_from vhost_limits" -f -a "delete" -d 'delete a vhost limit'
